"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path = require("path");
const wait_for_expect_1 = require("wait-for-expect");
const domLibraryAsString = fs_1.readFileSync(path.join(__dirname, '../dom-testing-library.js'), 'utf8').replace(/process.env/g, '{}');
/* istanbul ignore next */
function mapArgument(argument, index) {
    return index === 0 && typeof argument === 'object' && argument.regex
        ? new RegExp(argument.regex, argument.flags)
        : argument;
}
const delegateFnBodyToExecuteInPage = `
  ${domLibraryAsString};

  const mappedArgs = args.map(${mapArgument.toString()});
  const moduleWithFns = fnName in __dom_testing_library__ ?
    __dom_testing_library__ :
    __dom_testing_library__.__moduleExports;
  return moduleWithFns[fnName](container, ...mappedArgs);
`;
function createElementHandleArray(handle) {
    return __awaiter(this, void 0, void 0, function* () {
        const lengthHandle = yield handle.getProperty('length');
        const length = yield lengthHandle.jsonValue();
        const elements = [];
        for (let i = 0; i < length; i++) {
            const jsElement = yield handle.getProperty(i.toString());
            const element = yield createElementHandle(jsElement);
            if (element)
                elements.push(element);
        }
        return elements;
    });
}
function createElementHandle(handle) {
    return __awaiter(this, void 0, void 0, function* () {
        const element = handle.asElement();
        if (element)
            return element;
        yield handle.dispose();
        return null; // tslint:disable-line
    });
}
function covertToElementHandle(handle, asArray) {
    return __awaiter(this, void 0, void 0, function* () {
        return asArray ? createElementHandleArray(handle) : createElementHandle(handle);
    });
}
function processNodeText(handles) {
    return handles.containerHandle
        .executionContext()
        .evaluate(handles.evaluateFn, handles.containerHandle, 'getNodeText');
}
function processQuery(handles) {
    return __awaiter(this, void 0, void 0, function* () {
        const { containerHandle, evaluateFn, fnName, argsToForward } = handles;
        try {
            const handle = yield containerHandle
                .executionContext()
                .evaluateHandle(evaluateFn, containerHandle, fnName, ...argsToForward);
            return yield covertToElementHandle(handle, fnName.includes('All'));
        }
        catch (err) {
            err.message = err.message.replace('[fnName]', `[${fnName}]`);
            err.stack = err.stack.replace('[fnName]', `[${fnName}]`);
            throw err;
        }
    });
}
function createDelegateFor(fnName, contextFn, processHandleFn) {
    // @ts-ignore
    processHandleFn = processHandleFn || processQuery;
    const convertRegExp = (regex) => ({ regex: regex.source, flags: regex.flags });
    return function (...args) {
        return __awaiter(this, void 0, void 0, function* () {
            // @ts-ignore
            const containerHandle = contextFn ? contextFn.apply(this, args) : this;
            // @ts-ignore
            const evaluateFn = new Function('container, fnName, ...args', delegateFnBodyToExecuteInPage);
            // Convert RegExp to a special format since they don't serialize well
            let argsToForward = args.map(arg => (arg instanceof RegExp ? convertRegExp(arg) : arg));
            // Remove the container from the argsToForward since it's always the first argument
            if (containerHandle === args[0]) {
                argsToForward = args.slice(1);
            }
            return processHandleFn({ fnName, containerHandle, evaluateFn, argsToForward });
        });
    };
}
function getDocument(_page) {
    return __awaiter(this, void 0, void 0, function* () {
        // @ts-ignore
        const page = _page || this;
        const documentHandle = yield page.mainFrame().evaluateHandle('document');
        const document = documentHandle.asElement();
        if (!document)
            throw new Error('Could not find document');
        return document;
    });
}
exports.getDocument = getDocument;
function wait(callback = () => undefined, { timeout = 4500, interval = 50 } = {}) {
    return wait_for_expect_1.default(callback, timeout, interval);
}
exports.wait = wait;
function getQueriesForElement(object, contextFn) {
    const o = object;
    if (!contextFn)
        contextFn = () => o;
    o.getQueriesForElement = () => getQueriesForElement(o, () => o);
    o.queryByPlaceholderText = createDelegateFor('queryByPlaceholderText', contextFn);
    o.queryAllByPlaceholderText = createDelegateFor('queryAllByPlaceholderText', contextFn);
    o.getByPlaceholderText = createDelegateFor('getByPlaceholderText', contextFn);
    o.getAllByPlaceholderText = createDelegateFor('getAllByPlaceholderText', contextFn);
    o.queryByText = createDelegateFor('queryByText', contextFn);
    o.queryAllByText = createDelegateFor('queryAllByText', contextFn);
    o.getByText = createDelegateFor('getByText', contextFn);
    o.getAllByText = createDelegateFor('getAllByText', contextFn);
    o.queryByLabelText = createDelegateFor('queryByLabelText', contextFn);
    o.queryAllByLabelText = createDelegateFor('queryAllByLabelText', contextFn);
    o.getByLabelText = createDelegateFor('getByLabelText', contextFn);
    o.getAllByLabelText = createDelegateFor('getAllByLabelText', contextFn);
    o.queryByAltText = createDelegateFor('queryByAltText', contextFn);
    o.queryAllByAltText = createDelegateFor('queryAllByAltText', contextFn);
    o.getByAltText = createDelegateFor('getByAltText', contextFn);
    o.getAllByAltText = createDelegateFor('getAllByAltText', contextFn);
    o.queryByTestId = createDelegateFor('queryByTestId', contextFn);
    o.queryAllByTestId = createDelegateFor('queryAllByTestId', contextFn);
    o.getByTestId = createDelegateFor('getByTestId', contextFn);
    o.getAllByTestId = createDelegateFor('getAllByTestId', contextFn);
    o.queryByTitle = createDelegateFor('queryByTitle', contextFn);
    o.queryAllByTitle = createDelegateFor('queryAllByTitle', contextFn);
    o.getByTitle = createDelegateFor('getByTitle', contextFn);
    o.getAllByTitle = createDelegateFor('getAllByTitle', contextFn);
    o.queryByRole = createDelegateFor('queryByRole', contextFn);
    o.queryAllByRole = createDelegateFor('queryAllByRole', contextFn);
    o.getByRole = createDelegateFor('getByRole', contextFn);
    o.getAllByRole = createDelegateFor('getAllByRole', contextFn);
    o.queryByDisplayValue = createDelegateFor('queryByDisplayValue', contextFn);
    o.queryAllByDisplayValue = createDelegateFor('queryAllByDisplayValue', contextFn);
    o.getByDisplayValue = createDelegateFor('getByDisplayValue', contextFn);
    o.getAllByDisplayValue = createDelegateFor('getAllByDisplayValue', contextFn);
    o.getNodeText = createDelegateFor('getNodeText', contextFn, processNodeText);
    return o;
}
exports.getQueriesForElement = getQueriesForElement;
exports.within = getQueriesForElement;
// @ts-ignore
exports.queries = {};
getQueriesForElement(exports.queries, el => el);
//# sourceMappingURL=index.js.map