var __dom_testing_library__ = (function (exports) {
	'use strict';

	var commonjsGlobal = typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

	function unwrapExports (x) {
		return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
	}

	function createCommonjsModule(fn, module) {
		return module = { exports: {} }, fn(module, module.exports), module.exports;
	}

	var matches_1 = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.fuzzyMatches = fuzzyMatches;
	exports.matches = matches;
	exports.getDefaultNormalizer = getDefaultNormalizer;
	exports.makeNormalizer = makeNormalizer;

	function fuzzyMatches(textToMatch, node, matcher, normalizer) {
	  if (typeof textToMatch !== 'string') {
	    return false;
	  }

	  const normalizedText = normalizer(textToMatch);

	  if (typeof matcher === 'string') {
	    return normalizedText.toLowerCase().includes(matcher.toLowerCase());
	  } else if (typeof matcher === 'function') {
	    return matcher(normalizedText, node);
	  } else {
	    return matcher.test(normalizedText);
	  }
	}

	function matches(textToMatch, node, matcher, normalizer) {
	  if (typeof textToMatch !== 'string') {
	    return false;
	  }

	  const normalizedText = normalizer(textToMatch);

	  if (typeof matcher === 'string') {
	    return normalizedText === matcher;
	  } else if (typeof matcher === 'function') {
	    return matcher(normalizedText, node);
	  } else {
	    return matcher.test(normalizedText);
	  }
	}

	function getDefaultNormalizer({
	  trim = true,
	  collapseWhitespace = true
	} = {}) {
	  return text => {
	    let normalizedText = text;
	    normalizedText = trim ? normalizedText.trim() : normalizedText;
	    normalizedText = collapseWhitespace ? normalizedText.replace(/\s+/g, ' ') : normalizedText;
	    return normalizedText;
	  };
	}
	/**
	 * Constructs a normalizer to pass to functions in matches.js
	 * @param {boolean|undefined} trim The user-specified value for `trim`, without
	 * any defaulting having been applied
	 * @param {boolean|undefined} collapseWhitespace The user-specified value for
	 * `collapseWhitespace`, without any defaulting having been applied
	 * @param {Function|undefined} normalizer The user-specified normalizer
	 * @returns {Function} A normalizer
	 */


	function makeNormalizer({
	  trim,
	  collapseWhitespace,
	  normalizer
	}) {
	  if (normalizer) {
	    // User has specified a custom normalizer
	    if (typeof trim !== 'undefined' || typeof collapseWhitespace !== 'undefined') {
	      // They've also specified a value for trim or collapseWhitespace
	      throw new Error('trim and collapseWhitespace are not supported with a normalizer. ' + 'If you want to use the default trim and collapseWhitespace logic in your normalizer, ' + 'use "getDefaultNormalizer({trim, collapseWhitespace})" and compose that into your normalizer');
	    }

	    return normalizer;
	  } else {
	    // No custom normalizer specified. Just use default.
	    return getDefaultNormalizer({
	      trim,
	      collapseWhitespace
	    });
	  }
	}
	});

	unwrapExports(matches_1);
	var matches_2 = matches_1.fuzzyMatches;
	var matches_3 = matches_1.matches;
	var matches_4 = matches_1.getDefaultNormalizer;
	var matches_5 = matches_1.makeNormalizer;

	var getNodeText_1 = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.getNodeText = getNodeText;

	function getNodeText(node) {
	  const window = node.ownerDocument.defaultView;

	  if (node.matches('input[type=submit], input[type=button]')) {
	    return node.value;
	  }

	  return Array.from(node.childNodes).filter(child => child.nodeType === window.Node.TEXT_NODE && Boolean(child.textContent)).map(c => c.textContent).join('');
	}
	});

	unwrapExports(getNodeText_1);
	var getNodeText_2 = getNodeText_1.getNodeText;

	var interopRequireDefault = createCommonjsModule(function (module) {
	function _interopRequireDefault(obj) {
	  return obj && obj.__esModule ? obj : {
	    "default": obj
	  };
	}

	module.exports = _interopRequireDefault;
	});

	unwrapExports(interopRequireDefault);

	var _extends_1 = createCommonjsModule(function (module) {
	function _extends() {
	  module.exports = _extends = Object.assign || function (target) {
	    for (var i = 1; i < arguments.length; i++) {
	      var source = arguments[i];

	      for (var key in source) {
	        if (Object.prototype.hasOwnProperty.call(source, key)) {
	          target[key] = source[key];
	        }
	      }
	    }

	    return target;
	  };

	  return _extends.apply(this, arguments);
	}

	module.exports = _extends;
	});

	var colorName = {
		"aliceblue": [240, 248, 255],
		"antiquewhite": [250, 235, 215],
		"aqua": [0, 255, 255],
		"aquamarine": [127, 255, 212],
		"azure": [240, 255, 255],
		"beige": [245, 245, 220],
		"bisque": [255, 228, 196],
		"black": [0, 0, 0],
		"blanchedalmond": [255, 235, 205],
		"blue": [0, 0, 255],
		"blueviolet": [138, 43, 226],
		"brown": [165, 42, 42],
		"burlywood": [222, 184, 135],
		"cadetblue": [95, 158, 160],
		"chartreuse": [127, 255, 0],
		"chocolate": [210, 105, 30],
		"coral": [255, 127, 80],
		"cornflowerblue": [100, 149, 237],
		"cornsilk": [255, 248, 220],
		"crimson": [220, 20, 60],
		"cyan": [0, 255, 255],
		"darkblue": [0, 0, 139],
		"darkcyan": [0, 139, 139],
		"darkgoldenrod": [184, 134, 11],
		"darkgray": [169, 169, 169],
		"darkgreen": [0, 100, 0],
		"darkgrey": [169, 169, 169],
		"darkkhaki": [189, 183, 107],
		"darkmagenta": [139, 0, 139],
		"darkolivegreen": [85, 107, 47],
		"darkorange": [255, 140, 0],
		"darkorchid": [153, 50, 204],
		"darkred": [139, 0, 0],
		"darksalmon": [233, 150, 122],
		"darkseagreen": [143, 188, 143],
		"darkslateblue": [72, 61, 139],
		"darkslategray": [47, 79, 79],
		"darkslategrey": [47, 79, 79],
		"darkturquoise": [0, 206, 209],
		"darkviolet": [148, 0, 211],
		"deeppink": [255, 20, 147],
		"deepskyblue": [0, 191, 255],
		"dimgray": [105, 105, 105],
		"dimgrey": [105, 105, 105],
		"dodgerblue": [30, 144, 255],
		"firebrick": [178, 34, 34],
		"floralwhite": [255, 250, 240],
		"forestgreen": [34, 139, 34],
		"fuchsia": [255, 0, 255],
		"gainsboro": [220, 220, 220],
		"ghostwhite": [248, 248, 255],
		"gold": [255, 215, 0],
		"goldenrod": [218, 165, 32],
		"gray": [128, 128, 128],
		"green": [0, 128, 0],
		"greenyellow": [173, 255, 47],
		"grey": [128, 128, 128],
		"honeydew": [240, 255, 240],
		"hotpink": [255, 105, 180],
		"indianred": [205, 92, 92],
		"indigo": [75, 0, 130],
		"ivory": [255, 255, 240],
		"khaki": [240, 230, 140],
		"lavender": [230, 230, 250],
		"lavenderblush": [255, 240, 245],
		"lawngreen": [124, 252, 0],
		"lemonchiffon": [255, 250, 205],
		"lightblue": [173, 216, 230],
		"lightcoral": [240, 128, 128],
		"lightcyan": [224, 255, 255],
		"lightgoldenrodyellow": [250, 250, 210],
		"lightgray": [211, 211, 211],
		"lightgreen": [144, 238, 144],
		"lightgrey": [211, 211, 211],
		"lightpink": [255, 182, 193],
		"lightsalmon": [255, 160, 122],
		"lightseagreen": [32, 178, 170],
		"lightskyblue": [135, 206, 250],
		"lightslategray": [119, 136, 153],
		"lightslategrey": [119, 136, 153],
		"lightsteelblue": [176, 196, 222],
		"lightyellow": [255, 255, 224],
		"lime": [0, 255, 0],
		"limegreen": [50, 205, 50],
		"linen": [250, 240, 230],
		"magenta": [255, 0, 255],
		"maroon": [128, 0, 0],
		"mediumaquamarine": [102, 205, 170],
		"mediumblue": [0, 0, 205],
		"mediumorchid": [186, 85, 211],
		"mediumpurple": [147, 112, 219],
		"mediumseagreen": [60, 179, 113],
		"mediumslateblue": [123, 104, 238],
		"mediumspringgreen": [0, 250, 154],
		"mediumturquoise": [72, 209, 204],
		"mediumvioletred": [199, 21, 133],
		"midnightblue": [25, 25, 112],
		"mintcream": [245, 255, 250],
		"mistyrose": [255, 228, 225],
		"moccasin": [255, 228, 181],
		"navajowhite": [255, 222, 173],
		"navy": [0, 0, 128],
		"oldlace": [253, 245, 230],
		"olive": [128, 128, 0],
		"olivedrab": [107, 142, 35],
		"orange": [255, 165, 0],
		"orangered": [255, 69, 0],
		"orchid": [218, 112, 214],
		"palegoldenrod": [238, 232, 170],
		"palegreen": [152, 251, 152],
		"paleturquoise": [175, 238, 238],
		"palevioletred": [219, 112, 147],
		"papayawhip": [255, 239, 213],
		"peachpuff": [255, 218, 185],
		"peru": [205, 133, 63],
		"pink": [255, 192, 203],
		"plum": [221, 160, 221],
		"powderblue": [176, 224, 230],
		"purple": [128, 0, 128],
		"rebeccapurple": [102, 51, 153],
		"red": [255, 0, 0],
		"rosybrown": [188, 143, 143],
		"royalblue": [65, 105, 225],
		"saddlebrown": [139, 69, 19],
		"salmon": [250, 128, 114],
		"sandybrown": [244, 164, 96],
		"seagreen": [46, 139, 87],
		"seashell": [255, 245, 238],
		"sienna": [160, 82, 45],
		"silver": [192, 192, 192],
		"skyblue": [135, 206, 235],
		"slateblue": [106, 90, 205],
		"slategray": [112, 128, 144],
		"slategrey": [112, 128, 144],
		"snow": [255, 250, 250],
		"springgreen": [0, 255, 127],
		"steelblue": [70, 130, 180],
		"tan": [210, 180, 140],
		"teal": [0, 128, 128],
		"thistle": [216, 191, 216],
		"tomato": [255, 99, 71],
		"turquoise": [64, 224, 208],
		"violet": [238, 130, 238],
		"wheat": [245, 222, 179],
		"white": [255, 255, 255],
		"whitesmoke": [245, 245, 245],
		"yellow": [255, 255, 0],
		"yellowgreen": [154, 205, 50]
	};

	var conversions = createCommonjsModule(function (module) {
	/* MIT license */


	// NOTE: conversions should only return primitive values (i.e. arrays, or
	//       values that give correct `typeof` results).
	//       do not use box values types (i.e. Number(), String(), etc.)

	var reverseKeywords = {};
	for (var key in colorName) {
		if (colorName.hasOwnProperty(key)) {
			reverseKeywords[colorName[key]] = key;
		}
	}

	var convert = module.exports = {
		rgb: {channels: 3, labels: 'rgb'},
		hsl: {channels: 3, labels: 'hsl'},
		hsv: {channels: 3, labels: 'hsv'},
		hwb: {channels: 3, labels: 'hwb'},
		cmyk: {channels: 4, labels: 'cmyk'},
		xyz: {channels: 3, labels: 'xyz'},
		lab: {channels: 3, labels: 'lab'},
		lch: {channels: 3, labels: 'lch'},
		hex: {channels: 1, labels: ['hex']},
		keyword: {channels: 1, labels: ['keyword']},
		ansi16: {channels: 1, labels: ['ansi16']},
		ansi256: {channels: 1, labels: ['ansi256']},
		hcg: {channels: 3, labels: ['h', 'c', 'g']},
		apple: {channels: 3, labels: ['r16', 'g16', 'b16']},
		gray: {channels: 1, labels: ['gray']}
	};

	// hide .channels and .labels properties
	for (var model in convert) {
		if (convert.hasOwnProperty(model)) {
			if (!('channels' in convert[model])) {
				throw new Error('missing channels property: ' + model);
			}

			if (!('labels' in convert[model])) {
				throw new Error('missing channel labels property: ' + model);
			}

			if (convert[model].labels.length !== convert[model].channels) {
				throw new Error('channel and label counts mismatch: ' + model);
			}

			var channels = convert[model].channels;
			var labels = convert[model].labels;
			delete convert[model].channels;
			delete convert[model].labels;
			Object.defineProperty(convert[model], 'channels', {value: channels});
			Object.defineProperty(convert[model], 'labels', {value: labels});
		}
	}

	convert.rgb.hsl = function (rgb) {
		var r = rgb[0] / 255;
		var g = rgb[1] / 255;
		var b = rgb[2] / 255;
		var min = Math.min(r, g, b);
		var max = Math.max(r, g, b);
		var delta = max - min;
		var h;
		var s;
		var l;

		if (max === min) {
			h = 0;
		} else if (r === max) {
			h = (g - b) / delta;
		} else if (g === max) {
			h = 2 + (b - r) / delta;
		} else if (b === max) {
			h = 4 + (r - g) / delta;
		}

		h = Math.min(h * 60, 360);

		if (h < 0) {
			h += 360;
		}

		l = (min + max) / 2;

		if (max === min) {
			s = 0;
		} else if (l <= 0.5) {
			s = delta / (max + min);
		} else {
			s = delta / (2 - max - min);
		}

		return [h, s * 100, l * 100];
	};

	convert.rgb.hsv = function (rgb) {
		var rdif;
		var gdif;
		var bdif;
		var h;
		var s;

		var r = rgb[0] / 255;
		var g = rgb[1] / 255;
		var b = rgb[2] / 255;
		var v = Math.max(r, g, b);
		var diff = v - Math.min(r, g, b);
		var diffc = function (c) {
			return (v - c) / 6 / diff + 1 / 2;
		};

		if (diff === 0) {
			h = s = 0;
		} else {
			s = diff / v;
			rdif = diffc(r);
			gdif = diffc(g);
			bdif = diffc(b);

			if (r === v) {
				h = bdif - gdif;
			} else if (g === v) {
				h = (1 / 3) + rdif - bdif;
			} else if (b === v) {
				h = (2 / 3) + gdif - rdif;
			}
			if (h < 0) {
				h += 1;
			} else if (h > 1) {
				h -= 1;
			}
		}

		return [
			h * 360,
			s * 100,
			v * 100
		];
	};

	convert.rgb.hwb = function (rgb) {
		var r = rgb[0];
		var g = rgb[1];
		var b = rgb[2];
		var h = convert.rgb.hsl(rgb)[0];
		var w = 1 / 255 * Math.min(r, Math.min(g, b));

		b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));

		return [h, w * 100, b * 100];
	};

	convert.rgb.cmyk = function (rgb) {
		var r = rgb[0] / 255;
		var g = rgb[1] / 255;
		var b = rgb[2] / 255;
		var c;
		var m;
		var y;
		var k;

		k = Math.min(1 - r, 1 - g, 1 - b);
		c = (1 - r - k) / (1 - k) || 0;
		m = (1 - g - k) / (1 - k) || 0;
		y = (1 - b - k) / (1 - k) || 0;

		return [c * 100, m * 100, y * 100, k * 100];
	};

	/**
	 * See https://en.m.wikipedia.org/wiki/Euclidean_distance#Squared_Euclidean_distance
	 * */
	function comparativeDistance(x, y) {
		return (
			Math.pow(x[0] - y[0], 2) +
			Math.pow(x[1] - y[1], 2) +
			Math.pow(x[2] - y[2], 2)
		);
	}

	convert.rgb.keyword = function (rgb) {
		var reversed = reverseKeywords[rgb];
		if (reversed) {
			return reversed;
		}

		var currentClosestDistance = Infinity;
		var currentClosestKeyword;

		for (var keyword in colorName) {
			if (colorName.hasOwnProperty(keyword)) {
				var value = colorName[keyword];

				// Compute comparative distance
				var distance = comparativeDistance(rgb, value);

				// Check if its less, if so set as closest
				if (distance < currentClosestDistance) {
					currentClosestDistance = distance;
					currentClosestKeyword = keyword;
				}
			}
		}

		return currentClosestKeyword;
	};

	convert.keyword.rgb = function (keyword) {
		return colorName[keyword];
	};

	convert.rgb.xyz = function (rgb) {
		var r = rgb[0] / 255;
		var g = rgb[1] / 255;
		var b = rgb[2] / 255;

		// assume sRGB
		r = r > 0.04045 ? Math.pow(((r + 0.055) / 1.055), 2.4) : (r / 12.92);
		g = g > 0.04045 ? Math.pow(((g + 0.055) / 1.055), 2.4) : (g / 12.92);
		b = b > 0.04045 ? Math.pow(((b + 0.055) / 1.055), 2.4) : (b / 12.92);

		var x = (r * 0.4124) + (g * 0.3576) + (b * 0.1805);
		var y = (r * 0.2126) + (g * 0.7152) + (b * 0.0722);
		var z = (r * 0.0193) + (g * 0.1192) + (b * 0.9505);

		return [x * 100, y * 100, z * 100];
	};

	convert.rgb.lab = function (rgb) {
		var xyz = convert.rgb.xyz(rgb);
		var x = xyz[0];
		var y = xyz[1];
		var z = xyz[2];
		var l;
		var a;
		var b;

		x /= 95.047;
		y /= 100;
		z /= 108.883;

		x = x > 0.008856 ? Math.pow(x, 1 / 3) : (7.787 * x) + (16 / 116);
		y = y > 0.008856 ? Math.pow(y, 1 / 3) : (7.787 * y) + (16 / 116);
		z = z > 0.008856 ? Math.pow(z, 1 / 3) : (7.787 * z) + (16 / 116);

		l = (116 * y) - 16;
		a = 500 * (x - y);
		b = 200 * (y - z);

		return [l, a, b];
	};

	convert.hsl.rgb = function (hsl) {
		var h = hsl[0] / 360;
		var s = hsl[1] / 100;
		var l = hsl[2] / 100;
		var t1;
		var t2;
		var t3;
		var rgb;
		var val;

		if (s === 0) {
			val = l * 255;
			return [val, val, val];
		}

		if (l < 0.5) {
			t2 = l * (1 + s);
		} else {
			t2 = l + s - l * s;
		}

		t1 = 2 * l - t2;

		rgb = [0, 0, 0];
		for (var i = 0; i < 3; i++) {
			t3 = h + 1 / 3 * -(i - 1);
			if (t3 < 0) {
				t3++;
			}
			if (t3 > 1) {
				t3--;
			}

			if (6 * t3 < 1) {
				val = t1 + (t2 - t1) * 6 * t3;
			} else if (2 * t3 < 1) {
				val = t2;
			} else if (3 * t3 < 2) {
				val = t1 + (t2 - t1) * (2 / 3 - t3) * 6;
			} else {
				val = t1;
			}

			rgb[i] = val * 255;
		}

		return rgb;
	};

	convert.hsl.hsv = function (hsl) {
		var h = hsl[0];
		var s = hsl[1] / 100;
		var l = hsl[2] / 100;
		var smin = s;
		var lmin = Math.max(l, 0.01);
		var sv;
		var v;

		l *= 2;
		s *= (l <= 1) ? l : 2 - l;
		smin *= lmin <= 1 ? lmin : 2 - lmin;
		v = (l + s) / 2;
		sv = l === 0 ? (2 * smin) / (lmin + smin) : (2 * s) / (l + s);

		return [h, sv * 100, v * 100];
	};

	convert.hsv.rgb = function (hsv) {
		var h = hsv[0] / 60;
		var s = hsv[1] / 100;
		var v = hsv[2] / 100;
		var hi = Math.floor(h) % 6;

		var f = h - Math.floor(h);
		var p = 255 * v * (1 - s);
		var q = 255 * v * (1 - (s * f));
		var t = 255 * v * (1 - (s * (1 - f)));
		v *= 255;

		switch (hi) {
			case 0:
				return [v, t, p];
			case 1:
				return [q, v, p];
			case 2:
				return [p, v, t];
			case 3:
				return [p, q, v];
			case 4:
				return [t, p, v];
			case 5:
				return [v, p, q];
		}
	};

	convert.hsv.hsl = function (hsv) {
		var h = hsv[0];
		var s = hsv[1] / 100;
		var v = hsv[2] / 100;
		var vmin = Math.max(v, 0.01);
		var lmin;
		var sl;
		var l;

		l = (2 - s) * v;
		lmin = (2 - s) * vmin;
		sl = s * vmin;
		sl /= (lmin <= 1) ? lmin : 2 - lmin;
		sl = sl || 0;
		l /= 2;

		return [h, sl * 100, l * 100];
	};

	// http://dev.w3.org/csswg/css-color/#hwb-to-rgb
	convert.hwb.rgb = function (hwb) {
		var h = hwb[0] / 360;
		var wh = hwb[1] / 100;
		var bl = hwb[2] / 100;
		var ratio = wh + bl;
		var i;
		var v;
		var f;
		var n;

		// wh + bl cant be > 1
		if (ratio > 1) {
			wh /= ratio;
			bl /= ratio;
		}

		i = Math.floor(6 * h);
		v = 1 - bl;
		f = 6 * h - i;

		if ((i & 0x01) !== 0) {
			f = 1 - f;
		}

		n = wh + f * (v - wh); // linear interpolation

		var r;
		var g;
		var b;
		switch (i) {
			default:
			case 6:
			case 0: r = v; g = n; b = wh; break;
			case 1: r = n; g = v; b = wh; break;
			case 2: r = wh; g = v; b = n; break;
			case 3: r = wh; g = n; b = v; break;
			case 4: r = n; g = wh; b = v; break;
			case 5: r = v; g = wh; b = n; break;
		}

		return [r * 255, g * 255, b * 255];
	};

	convert.cmyk.rgb = function (cmyk) {
		var c = cmyk[0] / 100;
		var m = cmyk[1] / 100;
		var y = cmyk[2] / 100;
		var k = cmyk[3] / 100;
		var r;
		var g;
		var b;

		r = 1 - Math.min(1, c * (1 - k) + k);
		g = 1 - Math.min(1, m * (1 - k) + k);
		b = 1 - Math.min(1, y * (1 - k) + k);

		return [r * 255, g * 255, b * 255];
	};

	convert.xyz.rgb = function (xyz) {
		var x = xyz[0] / 100;
		var y = xyz[1] / 100;
		var z = xyz[2] / 100;
		var r;
		var g;
		var b;

		r = (x * 3.2406) + (y * -1.5372) + (z * -0.4986);
		g = (x * -0.9689) + (y * 1.8758) + (z * 0.0415);
		b = (x * 0.0557) + (y * -0.2040) + (z * 1.0570);

		// assume sRGB
		r = r > 0.0031308
			? ((1.055 * Math.pow(r, 1.0 / 2.4)) - 0.055)
			: r * 12.92;

		g = g > 0.0031308
			? ((1.055 * Math.pow(g, 1.0 / 2.4)) - 0.055)
			: g * 12.92;

		b = b > 0.0031308
			? ((1.055 * Math.pow(b, 1.0 / 2.4)) - 0.055)
			: b * 12.92;

		r = Math.min(Math.max(0, r), 1);
		g = Math.min(Math.max(0, g), 1);
		b = Math.min(Math.max(0, b), 1);

		return [r * 255, g * 255, b * 255];
	};

	convert.xyz.lab = function (xyz) {
		var x = xyz[0];
		var y = xyz[1];
		var z = xyz[2];
		var l;
		var a;
		var b;

		x /= 95.047;
		y /= 100;
		z /= 108.883;

		x = x > 0.008856 ? Math.pow(x, 1 / 3) : (7.787 * x) + (16 / 116);
		y = y > 0.008856 ? Math.pow(y, 1 / 3) : (7.787 * y) + (16 / 116);
		z = z > 0.008856 ? Math.pow(z, 1 / 3) : (7.787 * z) + (16 / 116);

		l = (116 * y) - 16;
		a = 500 * (x - y);
		b = 200 * (y - z);

		return [l, a, b];
	};

	convert.lab.xyz = function (lab) {
		var l = lab[0];
		var a = lab[1];
		var b = lab[2];
		var x;
		var y;
		var z;

		y = (l + 16) / 116;
		x = a / 500 + y;
		z = y - b / 200;

		var y2 = Math.pow(y, 3);
		var x2 = Math.pow(x, 3);
		var z2 = Math.pow(z, 3);
		y = y2 > 0.008856 ? y2 : (y - 16 / 116) / 7.787;
		x = x2 > 0.008856 ? x2 : (x - 16 / 116) / 7.787;
		z = z2 > 0.008856 ? z2 : (z - 16 / 116) / 7.787;

		x *= 95.047;
		y *= 100;
		z *= 108.883;

		return [x, y, z];
	};

	convert.lab.lch = function (lab) {
		var l = lab[0];
		var a = lab[1];
		var b = lab[2];
		var hr;
		var h;
		var c;

		hr = Math.atan2(b, a);
		h = hr * 360 / 2 / Math.PI;

		if (h < 0) {
			h += 360;
		}

		c = Math.sqrt(a * a + b * b);

		return [l, c, h];
	};

	convert.lch.lab = function (lch) {
		var l = lch[0];
		var c = lch[1];
		var h = lch[2];
		var a;
		var b;
		var hr;

		hr = h / 360 * 2 * Math.PI;
		a = c * Math.cos(hr);
		b = c * Math.sin(hr);

		return [l, a, b];
	};

	convert.rgb.ansi16 = function (args) {
		var r = args[0];
		var g = args[1];
		var b = args[2];
		var value = 1 in arguments ? arguments[1] : convert.rgb.hsv(args)[2]; // hsv -> ansi16 optimization

		value = Math.round(value / 50);

		if (value === 0) {
			return 30;
		}

		var ansi = 30
			+ ((Math.round(b / 255) << 2)
			| (Math.round(g / 255) << 1)
			| Math.round(r / 255));

		if (value === 2) {
			ansi += 60;
		}

		return ansi;
	};

	convert.hsv.ansi16 = function (args) {
		// optimization here; we already know the value and don't need to get
		// it converted for us.
		return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
	};

	convert.rgb.ansi256 = function (args) {
		var r = args[0];
		var g = args[1];
		var b = args[2];

		// we use the extended greyscale palette here, with the exception of
		// black and white. normal palette only has 4 greyscale shades.
		if (r === g && g === b) {
			if (r < 8) {
				return 16;
			}

			if (r > 248) {
				return 231;
			}

			return Math.round(((r - 8) / 247) * 24) + 232;
		}

		var ansi = 16
			+ (36 * Math.round(r / 255 * 5))
			+ (6 * Math.round(g / 255 * 5))
			+ Math.round(b / 255 * 5);

		return ansi;
	};

	convert.ansi16.rgb = function (args) {
		var color = args % 10;

		// handle greyscale
		if (color === 0 || color === 7) {
			if (args > 50) {
				color += 3.5;
			}

			color = color / 10.5 * 255;

			return [color, color, color];
		}

		var mult = (~~(args > 50) + 1) * 0.5;
		var r = ((color & 1) * mult) * 255;
		var g = (((color >> 1) & 1) * mult) * 255;
		var b = (((color >> 2) & 1) * mult) * 255;

		return [r, g, b];
	};

	convert.ansi256.rgb = function (args) {
		// handle greyscale
		if (args >= 232) {
			var c = (args - 232) * 10 + 8;
			return [c, c, c];
		}

		args -= 16;

		var rem;
		var r = Math.floor(args / 36) / 5 * 255;
		var g = Math.floor((rem = args % 36) / 6) / 5 * 255;
		var b = (rem % 6) / 5 * 255;

		return [r, g, b];
	};

	convert.rgb.hex = function (args) {
		var integer = ((Math.round(args[0]) & 0xFF) << 16)
			+ ((Math.round(args[1]) & 0xFF) << 8)
			+ (Math.round(args[2]) & 0xFF);

		var string = integer.toString(16).toUpperCase();
		return '000000'.substring(string.length) + string;
	};

	convert.hex.rgb = function (args) {
		var match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
		if (!match) {
			return [0, 0, 0];
		}

		var colorString = match[0];

		if (match[0].length === 3) {
			colorString = colorString.split('').map(function (char) {
				return char + char;
			}).join('');
		}

		var integer = parseInt(colorString, 16);
		var r = (integer >> 16) & 0xFF;
		var g = (integer >> 8) & 0xFF;
		var b = integer & 0xFF;

		return [r, g, b];
	};

	convert.rgb.hcg = function (rgb) {
		var r = rgb[0] / 255;
		var g = rgb[1] / 255;
		var b = rgb[2] / 255;
		var max = Math.max(Math.max(r, g), b);
		var min = Math.min(Math.min(r, g), b);
		var chroma = (max - min);
		var grayscale;
		var hue;

		if (chroma < 1) {
			grayscale = min / (1 - chroma);
		} else {
			grayscale = 0;
		}

		if (chroma <= 0) {
			hue = 0;
		} else
		if (max === r) {
			hue = ((g - b) / chroma) % 6;
		} else
		if (max === g) {
			hue = 2 + (b - r) / chroma;
		} else {
			hue = 4 + (r - g) / chroma + 4;
		}

		hue /= 6;
		hue %= 1;

		return [hue * 360, chroma * 100, grayscale * 100];
	};

	convert.hsl.hcg = function (hsl) {
		var s = hsl[1] / 100;
		var l = hsl[2] / 100;
		var c = 1;
		var f = 0;

		if (l < 0.5) {
			c = 2.0 * s * l;
		} else {
			c = 2.0 * s * (1.0 - l);
		}

		if (c < 1.0) {
			f = (l - 0.5 * c) / (1.0 - c);
		}

		return [hsl[0], c * 100, f * 100];
	};

	convert.hsv.hcg = function (hsv) {
		var s = hsv[1] / 100;
		var v = hsv[2] / 100;

		var c = s * v;
		var f = 0;

		if (c < 1.0) {
			f = (v - c) / (1 - c);
		}

		return [hsv[0], c * 100, f * 100];
	};

	convert.hcg.rgb = function (hcg) {
		var h = hcg[0] / 360;
		var c = hcg[1] / 100;
		var g = hcg[2] / 100;

		if (c === 0.0) {
			return [g * 255, g * 255, g * 255];
		}

		var pure = [0, 0, 0];
		var hi = (h % 1) * 6;
		var v = hi % 1;
		var w = 1 - v;
		var mg = 0;

		switch (Math.floor(hi)) {
			case 0:
				pure[0] = 1; pure[1] = v; pure[2] = 0; break;
			case 1:
				pure[0] = w; pure[1] = 1; pure[2] = 0; break;
			case 2:
				pure[0] = 0; pure[1] = 1; pure[2] = v; break;
			case 3:
				pure[0] = 0; pure[1] = w; pure[2] = 1; break;
			case 4:
				pure[0] = v; pure[1] = 0; pure[2] = 1; break;
			default:
				pure[0] = 1; pure[1] = 0; pure[2] = w;
		}

		mg = (1.0 - c) * g;

		return [
			(c * pure[0] + mg) * 255,
			(c * pure[1] + mg) * 255,
			(c * pure[2] + mg) * 255
		];
	};

	convert.hcg.hsv = function (hcg) {
		var c = hcg[1] / 100;
		var g = hcg[2] / 100;

		var v = c + g * (1.0 - c);
		var f = 0;

		if (v > 0.0) {
			f = c / v;
		}

		return [hcg[0], f * 100, v * 100];
	};

	convert.hcg.hsl = function (hcg) {
		var c = hcg[1] / 100;
		var g = hcg[2] / 100;

		var l = g * (1.0 - c) + 0.5 * c;
		var s = 0;

		if (l > 0.0 && l < 0.5) {
			s = c / (2 * l);
		} else
		if (l >= 0.5 && l < 1.0) {
			s = c / (2 * (1 - l));
		}

		return [hcg[0], s * 100, l * 100];
	};

	convert.hcg.hwb = function (hcg) {
		var c = hcg[1] / 100;
		var g = hcg[2] / 100;
		var v = c + g * (1.0 - c);
		return [hcg[0], (v - c) * 100, (1 - v) * 100];
	};

	convert.hwb.hcg = function (hwb) {
		var w = hwb[1] / 100;
		var b = hwb[2] / 100;
		var v = 1 - b;
		var c = v - w;
		var g = 0;

		if (c < 1) {
			g = (v - c) / (1 - c);
		}

		return [hwb[0], c * 100, g * 100];
	};

	convert.apple.rgb = function (apple) {
		return [(apple[0] / 65535) * 255, (apple[1] / 65535) * 255, (apple[2] / 65535) * 255];
	};

	convert.rgb.apple = function (rgb) {
		return [(rgb[0] / 255) * 65535, (rgb[1] / 255) * 65535, (rgb[2] / 255) * 65535];
	};

	convert.gray.rgb = function (args) {
		return [args[0] / 100 * 255, args[0] / 100 * 255, args[0] / 100 * 255];
	};

	convert.gray.hsl = convert.gray.hsv = function (args) {
		return [0, 0, args[0]];
	};

	convert.gray.hwb = function (gray) {
		return [0, 100, gray[0]];
	};

	convert.gray.cmyk = function (gray) {
		return [0, 0, 0, gray[0]];
	};

	convert.gray.lab = function (gray) {
		return [gray[0], 0, 0];
	};

	convert.gray.hex = function (gray) {
		var val = Math.round(gray[0] / 100 * 255) & 0xFF;
		var integer = (val << 16) + (val << 8) + val;

		var string = integer.toString(16).toUpperCase();
		return '000000'.substring(string.length) + string;
	};

	convert.rgb.gray = function (rgb) {
		var val = (rgb[0] + rgb[1] + rgb[2]) / 3;
		return [val / 255 * 100];
	};
	});
	var conversions_1 = conversions.rgb;
	var conversions_2 = conversions.hsl;
	var conversions_3 = conversions.hsv;
	var conversions_4 = conversions.hwb;
	var conversions_5 = conversions.cmyk;
	var conversions_6 = conversions.xyz;
	var conversions_7 = conversions.lab;
	var conversions_8 = conversions.lch;
	var conversions_9 = conversions.hex;
	var conversions_10 = conversions.keyword;
	var conversions_11 = conversions.ansi16;
	var conversions_12 = conversions.ansi256;
	var conversions_13 = conversions.hcg;
	var conversions_14 = conversions.apple;
	var conversions_15 = conversions.gray;

	/*
		this function routes a model to all other models.

		all functions that are routed have a property `.conversion` attached
		to the returned synthetic function. This property is an array
		of strings, each with the steps in between the 'from' and 'to'
		color models (inclusive).

		conversions that are not possible simply are not included.
	*/

	function buildGraph() {
		var graph = {};
		// https://jsperf.com/object-keys-vs-for-in-with-closure/3
		var models = Object.keys(conversions);

		for (var len = models.length, i = 0; i < len; i++) {
			graph[models[i]] = {
				// http://jsperf.com/1-vs-infinity
				// micro-opt, but this is simple.
				distance: -1,
				parent: null
			};
		}

		return graph;
	}

	// https://en.wikipedia.org/wiki/Breadth-first_search
	function deriveBFS(fromModel) {
		var graph = buildGraph();
		var queue = [fromModel]; // unshift -> queue -> pop

		graph[fromModel].distance = 0;

		while (queue.length) {
			var current = queue.pop();
			var adjacents = Object.keys(conversions[current]);

			for (var len = adjacents.length, i = 0; i < len; i++) {
				var adjacent = adjacents[i];
				var node = graph[adjacent];

				if (node.distance === -1) {
					node.distance = graph[current].distance + 1;
					node.parent = current;
					queue.unshift(adjacent);
				}
			}
		}

		return graph;
	}

	function link(from, to) {
		return function (args) {
			return to(from(args));
		};
	}

	function wrapConversion(toModel, graph) {
		var path = [graph[toModel].parent, toModel];
		var fn = conversions[graph[toModel].parent][toModel];

		var cur = graph[toModel].parent;
		while (graph[cur].parent) {
			path.unshift(graph[cur].parent);
			fn = link(conversions[graph[cur].parent][cur], fn);
			cur = graph[cur].parent;
		}

		fn.conversion = path;
		return fn;
	}

	var route = function (fromModel) {
		var graph = deriveBFS(fromModel);
		var conversion = {};

		var models = Object.keys(graph);
		for (var len = models.length, i = 0; i < len; i++) {
			var toModel = models[i];
			var node = graph[toModel];

			if (node.parent === null) {
				// no possible conversion, or this node is the source model.
				continue;
			}

			conversion[toModel] = wrapConversion(toModel, graph);
		}

		return conversion;
	};

	var convert = {};

	var models = Object.keys(conversions);

	function wrapRaw(fn) {
		var wrappedFn = function (args) {
			if (args === undefined || args === null) {
				return args;
			}

			if (arguments.length > 1) {
				args = Array.prototype.slice.call(arguments);
			}

			return fn(args);
		};

		// preserve .conversion property if there is one
		if ('conversion' in fn) {
			wrappedFn.conversion = fn.conversion;
		}

		return wrappedFn;
	}

	function wrapRounded(fn) {
		var wrappedFn = function (args) {
			if (args === undefined || args === null) {
				return args;
			}

			if (arguments.length > 1) {
				args = Array.prototype.slice.call(arguments);
			}

			var result = fn(args);

			// we're assuming the result is an array here.
			// see notice in conversions.js; don't use box types
			// in conversion functions.
			if (typeof result === 'object') {
				for (var len = result.length, i = 0; i < len; i++) {
					result[i] = Math.round(result[i]);
				}
			}

			return result;
		};

		// preserve .conversion property if there is one
		if ('conversion' in fn) {
			wrappedFn.conversion = fn.conversion;
		}

		return wrappedFn;
	}

	models.forEach(function (fromModel) {
		convert[fromModel] = {};

		Object.defineProperty(convert[fromModel], 'channels', {value: conversions[fromModel].channels});
		Object.defineProperty(convert[fromModel], 'labels', {value: conversions[fromModel].labels});

		var routes = route(fromModel);
		var routeModels = Object.keys(routes);

		routeModels.forEach(function (toModel) {
			var fn = routes[toModel];

			convert[fromModel][toModel] = wrapRounded(fn);
			convert[fromModel][toModel].raw = wrapRaw(fn);
		});
	});

	var colorConvert = convert;

	var ansiStyles = createCommonjsModule(function (module) {


	const wrapAnsi16 = (fn, offset) => function () {
		const code = fn.apply(colorConvert, arguments);
		return `\u001B[${code + offset}m`;
	};

	const wrapAnsi256 = (fn, offset) => function () {
		const code = fn.apply(colorConvert, arguments);
		return `\u001B[${38 + offset};5;${code}m`;
	};

	const wrapAnsi16m = (fn, offset) => function () {
		const rgb = fn.apply(colorConvert, arguments);
		return `\u001B[${38 + offset};2;${rgb[0]};${rgb[1]};${rgb[2]}m`;
	};

	function assembleStyles() {
		const codes = new Map();
		const styles = {
			modifier: {
				reset: [0, 0],
				// 21 isn't widely supported and 22 does the same thing
				bold: [1, 22],
				dim: [2, 22],
				italic: [3, 23],
				underline: [4, 24],
				inverse: [7, 27],
				hidden: [8, 28],
				strikethrough: [9, 29]
			},
			color: {
				black: [30, 39],
				red: [31, 39],
				green: [32, 39],
				yellow: [33, 39],
				blue: [34, 39],
				magenta: [35, 39],
				cyan: [36, 39],
				white: [37, 39],
				gray: [90, 39],

				// Bright color
				redBright: [91, 39],
				greenBright: [92, 39],
				yellowBright: [93, 39],
				blueBright: [94, 39],
				magentaBright: [95, 39],
				cyanBright: [96, 39],
				whiteBright: [97, 39]
			},
			bgColor: {
				bgBlack: [40, 49],
				bgRed: [41, 49],
				bgGreen: [42, 49],
				bgYellow: [43, 49],
				bgBlue: [44, 49],
				bgMagenta: [45, 49],
				bgCyan: [46, 49],
				bgWhite: [47, 49],

				// Bright color
				bgBlackBright: [100, 49],
				bgRedBright: [101, 49],
				bgGreenBright: [102, 49],
				bgYellowBright: [103, 49],
				bgBlueBright: [104, 49],
				bgMagentaBright: [105, 49],
				bgCyanBright: [106, 49],
				bgWhiteBright: [107, 49]
			}
		};

		// Fix humans
		styles.color.grey = styles.color.gray;

		for (const groupName of Object.keys(styles)) {
			const group = styles[groupName];

			for (const styleName of Object.keys(group)) {
				const style = group[styleName];

				styles[styleName] = {
					open: `\u001B[${style[0]}m`,
					close: `\u001B[${style[1]}m`
				};

				group[styleName] = styles[styleName];

				codes.set(style[0], style[1]);
			}

			Object.defineProperty(styles, groupName, {
				value: group,
				enumerable: false
			});

			Object.defineProperty(styles, 'codes', {
				value: codes,
				enumerable: false
			});
		}

		const ansi2ansi = n => n;
		const rgb2rgb = (r, g, b) => [r, g, b];

		styles.color.close = '\u001B[39m';
		styles.bgColor.close = '\u001B[49m';

		styles.color.ansi = {
			ansi: wrapAnsi16(ansi2ansi, 0)
		};
		styles.color.ansi256 = {
			ansi256: wrapAnsi256(ansi2ansi, 0)
		};
		styles.color.ansi16m = {
			rgb: wrapAnsi16m(rgb2rgb, 0)
		};

		styles.bgColor.ansi = {
			ansi: wrapAnsi16(ansi2ansi, 10)
		};
		styles.bgColor.ansi256 = {
			ansi256: wrapAnsi256(ansi2ansi, 10)
		};
		styles.bgColor.ansi16m = {
			rgb: wrapAnsi16m(rgb2rgb, 10)
		};

		for (let key of Object.keys(colorConvert)) {
			if (typeof colorConvert[key] !== 'object') {
				continue;
			}

			const suite = colorConvert[key];

			if (key === 'ansi16') {
				key = 'ansi';
			}

			if ('ansi16' in suite) {
				styles.color.ansi[key] = wrapAnsi16(suite.ansi16, 0);
				styles.bgColor.ansi[key] = wrapAnsi16(suite.ansi16, 10);
			}

			if ('ansi256' in suite) {
				styles.color.ansi256[key] = wrapAnsi256(suite.ansi256, 0);
				styles.bgColor.ansi256[key] = wrapAnsi256(suite.ansi256, 10);
			}

			if ('rgb' in suite) {
				styles.color.ansi16m[key] = wrapAnsi16m(suite.rgb, 0);
				styles.bgColor.ansi16m[key] = wrapAnsi16m(suite.rgb, 10);
			}
		}

		return styles;
	}

	// Make the export immutable
	Object.defineProperty(module, 'exports', {
		enumerable: true,
		get: assembleStyles
	});
	});

	var collections = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.printIteratorEntries = printIteratorEntries;
	exports.printIteratorValues = printIteratorValues;
	exports.printListItems = printListItems;
	exports.printObjectProperties = printObjectProperties;

	/**
	 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
	 *
	 * This source code is licensed under the MIT license found in the
	 * LICENSE file in the root directory of this source tree.
	 *
	 */
	const getKeysOfEnumerableProperties = object => {
	  const keys = Object.keys(object).sort();

	  if (Object.getOwnPropertySymbols) {
	    Object.getOwnPropertySymbols(object).forEach(symbol => {
	      if (Object.getOwnPropertyDescriptor(object, symbol).enumerable) {
	        keys.push(symbol);
	      }
	    });
	  }

	  return keys;
	};
	/**
	 * Return entries (for example, of a map)
	 * with spacing, indentation, and comma
	 * without surrounding punctuation (for example, braces)
	 */

	function printIteratorEntries( // Flow 0.51.0: property `@@iterator` of $Iterator not found in Object
	  // To allow simplistic getRecordIterator in immutable.js
	  iterator,
	  config,
	  indentation,
	  depth,
	  refs,
	  printer, // Too bad, so sad that separator for ECMAScript Map has been ' => '
	  // What a distracting diff if you change a data structure to/from
	  separator = ': '
	) {
	  let result = '';
	  let current = iterator.next();

	  if (!current.done) {
	    result += config.spacingOuter;
	    const indentationNext = indentation + config.indent;

	    while (!current.done) {
	      const name = printer(
	        current.value[0],
	        config,
	        indentationNext,
	        depth,
	        refs
	      );
	      const value = printer(
	        current.value[1],
	        config,
	        indentationNext,
	        depth,
	        refs
	      );
	      result += indentationNext + name + separator + value;
	      current = iterator.next();

	      if (!current.done) {
	        result += ',' + config.spacingInner;
	      } else if (!config.min) {
	        result += ',';
	      }
	    }

	    result += config.spacingOuter + indentation;
	  }

	  return result;
	}
	/**
	 * Return values (for example, of a set)
	 * with spacing, indentation, and comma
	 * without surrounding punctuation (braces or brackets)
	 */

	function printIteratorValues(
	  iterator,
	  config,
	  indentation,
	  depth,
	  refs,
	  printer
	) {
	  let result = '';
	  let current = iterator.next();

	  if (!current.done) {
	    result += config.spacingOuter;
	    const indentationNext = indentation + config.indent;

	    while (!current.done) {
	      result +=
	        indentationNext +
	        printer(current.value, config, indentationNext, depth, refs);
	      current = iterator.next();

	      if (!current.done) {
	        result += ',' + config.spacingInner;
	      } else if (!config.min) {
	        result += ',';
	      }
	    }

	    result += config.spacingOuter + indentation;
	  }

	  return result;
	}
	/**
	 * Return items (for example, of an array)
	 * with spacing, indentation, and comma
	 * without surrounding punctuation (for example, brackets)
	 **/

	function printListItems(list, config, indentation, depth, refs, printer) {
	  let result = '';

	  if (list.length) {
	    result += config.spacingOuter;
	    const indentationNext = indentation + config.indent;

	    for (let i = 0; i < list.length; i++) {
	      result +=
	        indentationNext +
	        printer(list[i], config, indentationNext, depth, refs);

	      if (i < list.length - 1) {
	        result += ',' + config.spacingInner;
	      } else if (!config.min) {
	        result += ',';
	      }
	    }

	    result += config.spacingOuter + indentation;
	  }

	  return result;
	}
	/**
	 * Return properties of an object
	 * with spacing, indentation, and comma
	 * without surrounding punctuation (for example, braces)
	 */

	function printObjectProperties(val, config, indentation, depth, refs, printer) {
	  let result = '';
	  const keys = getKeysOfEnumerableProperties(val);

	  if (keys.length) {
	    result += config.spacingOuter;
	    const indentationNext = indentation + config.indent;

	    for (let i = 0; i < keys.length; i++) {
	      const key = keys[i];
	      const name = printer(key, config, indentationNext, depth, refs);
	      const value = printer(val[key], config, indentationNext, depth, refs);
	      result += indentationNext + name + ': ' + value;

	      if (i < keys.length - 1) {
	        result += ',' + config.spacingInner;
	      } else if (!config.min) {
	        result += ',';
	      }
	    }

	    result += config.spacingOuter + indentation;
	  }

	  return result;
	}
	});

	unwrapExports(collections);
	var collections_1 = collections.printIteratorEntries;
	var collections_2 = collections.printIteratorValues;
	var collections_3 = collections.printListItems;
	var collections_4 = collections.printObjectProperties;

	var AsymmetricMatcher = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = exports.test = exports.serialize = void 0;



	var Symbol = commonjsGlobal['jest-symbol-do-not-touch'] || commonjsGlobal.Symbol;
	const asymmetricMatcher = Symbol.for('jest.asymmetricMatcher');
	const SPACE = ' ';

	const serialize = (val, config, indentation, depth, refs, printer) => {
	  const stringedValue = val.toString();

	  if (
	    stringedValue === 'ArrayContaining' ||
	    stringedValue === 'ArrayNotContaining'
	  ) {
	    if (++depth > config.maxDepth) {
	      return '[' + stringedValue + ']';
	    }

	    return (
	      stringedValue +
	      SPACE +
	      '[' +
	      (0, collections.printListItems)(
	        val.sample,
	        config,
	        indentation,
	        depth,
	        refs,
	        printer
	      ) +
	      ']'
	    );
	  }

	  if (
	    stringedValue === 'ObjectContaining' ||
	    stringedValue === 'ObjectNotContaining'
	  ) {
	    if (++depth > config.maxDepth) {
	      return '[' + stringedValue + ']';
	    }

	    return (
	      stringedValue +
	      SPACE +
	      '{' +
	      (0, collections.printObjectProperties)(
	        val.sample,
	        config,
	        indentation,
	        depth,
	        refs,
	        printer
	      ) +
	      '}'
	    );
	  }

	  if (
	    stringedValue === 'StringMatching' ||
	    stringedValue === 'StringNotMatching'
	  ) {
	    return (
	      stringedValue +
	      SPACE +
	      printer(val.sample, config, indentation, depth, refs)
	    );
	  }

	  if (
	    stringedValue === 'StringContaining' ||
	    stringedValue === 'StringNotContaining'
	  ) {
	    return (
	      stringedValue +
	      SPACE +
	      printer(val.sample, config, indentation, depth, refs)
	    );
	  }

	  return val.toAsymmetricMatcher();
	};

	exports.serialize = serialize;

	const test = val => val && val.$$typeof === asymmetricMatcher;

	exports.test = test;
	const plugin = {
	  serialize,
	  test
	};
	var _default = plugin;
	exports.default = _default;
	});

	unwrapExports(AsymmetricMatcher);
	var AsymmetricMatcher_1 = AsymmetricMatcher.test;
	var AsymmetricMatcher_2 = AsymmetricMatcher.serialize;

	var ansiRegex = options => {
		options = Object.assign({
			onlyFirst: false
		}, options);

		const pattern = [
			'[\\u001B\\u009B][[\\]()#;?]*(?:(?:(?:[a-zA-Z\\d]*(?:;[-a-zA-Z\\d\\/#&.:=?%@~_]*)*)?\\u0007)',
			'(?:(?:\\d{1,4}(?:;\\d{0,4})*)?[\\dA-PR-TZcf-ntqry=><~]))'
		].join('|');

		return new RegExp(pattern, options.onlyFirst ? undefined : 'g');
	};

	var ConvertAnsi = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = exports.serialize = exports.test = void 0;

	var _ansiRegex = _interopRequireDefault(ansiRegex);

	var _ansiStyles = _interopRequireDefault(ansiStyles);

	function _interopRequireDefault(obj) {
	  return obj && obj.__esModule ? obj : {default: obj};
	}

	/**
	 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
	 *
	 * This source code is licensed under the MIT license found in the
	 * LICENSE file in the root directory of this source tree.
	 */
	const toHumanReadableAnsi = text =>
	  text.replace((0, _ansiRegex.default)(), match => {
	    switch (match) {
	      case _ansiStyles.default.red.close:
	      case _ansiStyles.default.green.close:
	      case _ansiStyles.default.cyan.close:
	      case _ansiStyles.default.gray.close:
	      case _ansiStyles.default.white.close:
	      case _ansiStyles.default.yellow.close:
	      case _ansiStyles.default.bgRed.close:
	      case _ansiStyles.default.bgGreen.close:
	      case _ansiStyles.default.bgYellow.close:
	      case _ansiStyles.default.inverse.close:
	      case _ansiStyles.default.dim.close:
	      case _ansiStyles.default.bold.close:
	      case _ansiStyles.default.reset.open:
	      case _ansiStyles.default.reset.close:
	        return '</>';

	      case _ansiStyles.default.red.open:
	        return '<red>';

	      case _ansiStyles.default.green.open:
	        return '<green>';

	      case _ansiStyles.default.cyan.open:
	        return '<cyan>';

	      case _ansiStyles.default.gray.open:
	        return '<gray>';

	      case _ansiStyles.default.white.open:
	        return '<white>';

	      case _ansiStyles.default.yellow.open:
	        return '<yellow>';

	      case _ansiStyles.default.bgRed.open:
	        return '<bgRed>';

	      case _ansiStyles.default.bgGreen.open:
	        return '<bgGreen>';

	      case _ansiStyles.default.bgYellow.open:
	        return '<bgYellow>';

	      case _ansiStyles.default.inverse.open:
	        return '<inverse>';

	      case _ansiStyles.default.dim.open:
	        return '<dim>';

	      case _ansiStyles.default.bold.open:
	        return '<bold>';

	      default:
	        return '';
	    }
	  });

	const test = val =>
	  typeof val === 'string' && !!val.match((0, _ansiRegex.default)());

	exports.test = test;

	const serialize = (val, config, indentation, depth, refs, printer) =>
	  printer(toHumanReadableAnsi(val), config, indentation, depth, refs);

	exports.serialize = serialize;
	const plugin = {
	  serialize,
	  test
	};
	var _default = plugin;
	exports.default = _default;
	});

	unwrapExports(ConvertAnsi);
	var ConvertAnsi_1 = ConvertAnsi.serialize;
	var ConvertAnsi_2 = ConvertAnsi.test;

	var DOMCollection = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = exports.serialize = exports.test = void 0;



	function _objectSpread(target) {
	  for (var i = 1; i < arguments.length; i++) {
	    var source = arguments[i] != null ? arguments[i] : {};
	    var ownKeys = Object.keys(source);
	    if (typeof Object.getOwnPropertySymbols === 'function') {
	      ownKeys = ownKeys.concat(
	        Object.getOwnPropertySymbols(source).filter(function(sym) {
	          return Object.getOwnPropertyDescriptor(source, sym).enumerable;
	        })
	      );
	    }
	    ownKeys.forEach(function(key) {
	      _defineProperty(target, key, source[key]);
	    });
	  }
	  return target;
	}

	function _defineProperty(obj, key, value) {
	  if (key in obj) {
	    Object.defineProperty(obj, key, {
	      value: value,
	      enumerable: true,
	      configurable: true,
	      writable: true
	    });
	  } else {
	    obj[key] = value;
	  }
	  return obj;
	}

	const SPACE = ' ';
	const OBJECT_NAMES = ['DOMStringMap', 'NamedNodeMap'];
	const ARRAY_REGEXP = /^(HTML\w*Collection|NodeList)$/;

	const testName = name =>
	  OBJECT_NAMES.indexOf(name) !== -1 || ARRAY_REGEXP.test(name);

	const test = val =>
	  val &&
	  val.constructor &&
	  val.constructor.name &&
	  testName(val.constructor.name); // Convert array of attribute objects to props object.

	exports.test = test;

	const propsReducer = (props, attribute) => {
	  props[attribute.name] = attribute.value;
	  return props;
	};

	const serialize = (collection, config, indentation, depth, refs, printer) => {
	  const name = collection.constructor.name;

	  if (++depth > config.maxDepth) {
	    return '[' + name + ']';
	  }

	  return (
	    (config.min ? '' : name + SPACE) +
	    (OBJECT_NAMES.indexOf(name) !== -1
	      ? '{' +
	        (0, collections.printObjectProperties)(
	          name === 'NamedNodeMap'
	            ? Array.prototype.reduce.call(collection, propsReducer, {})
	            : _objectSpread({}, collection),
	          config,
	          indentation,
	          depth,
	          refs,
	          printer
	        ) +
	        '}'
	      : '[' +
	        (0, collections.printListItems)(
	          Array.from(collection),
	          config,
	          indentation,
	          depth,
	          refs,
	          printer
	        ) +
	        ']')
	  );
	};

	exports.serialize = serialize;
	const plugin = {
	  serialize,
	  test
	};
	var _default = plugin;
	exports.default = _default;
	});

	unwrapExports(DOMCollection);
	var DOMCollection_1 = DOMCollection.serialize;
	var DOMCollection_2 = DOMCollection.test;

	var escapeHTML_1 = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = escapeHTML;

	/**
	 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
	 *
	 * This source code is licensed under the MIT license found in the
	 * LICENSE file in the root directory of this source tree.
	 */
	function escapeHTML(str) {
	  return str.replace(/</g, '&lt;').replace(/>/g, '&gt;');
	}
	});

	unwrapExports(escapeHTML_1);

	var markup = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.printElementAsLeaf = exports.printElement = exports.printComment = exports.printText = exports.printChildren = exports.printProps = void 0;

	var _escapeHTML = _interopRequireDefault(escapeHTML_1);

	function _interopRequireDefault(obj) {
	  return obj && obj.__esModule ? obj : {default: obj};
	}

	/**
	 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
	 *
	 * This source code is licensed under the MIT license found in the
	 * LICENSE file in the root directory of this source tree.
	 */
	// Return empty string if keys is empty.
	const printProps = (keys, props, config, indentation, depth, refs, printer) => {
	  const indentationNext = indentation + config.indent;
	  const colors = config.colors;
	  return keys
	    .map(key => {
	      const value = props[key];
	      let printed = printer(value, config, indentationNext, depth, refs);

	      if (typeof value !== 'string') {
	        if (printed.indexOf('\n') !== -1) {
	          printed =
	            config.spacingOuter +
	            indentationNext +
	            printed +
	            config.spacingOuter +
	            indentation;
	        }

	        printed = '{' + printed + '}';
	      }

	      return (
	        config.spacingInner +
	        indentation +
	        colors.prop.open +
	        key +
	        colors.prop.close +
	        '=' +
	        colors.value.open +
	        printed +
	        colors.value.close
	      );
	    })
	    .join('');
	}; // Return empty string if children is empty.

	exports.printProps = printProps;

	const printChildren = (children, config, indentation, depth, refs, printer) =>
	  children
	    .map(
	      child =>
	        config.spacingOuter +
	        indentation +
	        (typeof child === 'string'
	          ? printText(child, config)
	          : printer(child, config, indentation, depth, refs))
	    )
	    .join('');

	exports.printChildren = printChildren;

	const printText = (text, config) => {
	  const contentColor = config.colors.content;
	  return (
	    contentColor.open + (0, _escapeHTML.default)(text) + contentColor.close
	  );
	};

	exports.printText = printText;

	const printComment = (comment, config) => {
	  const commentColor = config.colors.comment;
	  return (
	    commentColor.open +
	    '<!--' +
	    (0, _escapeHTML.default)(comment) +
	    '-->' +
	    commentColor.close
	  );
	}; // Separate the functions to format props, children, and element,
	// so a plugin could override a particular function, if needed.
	// Too bad, so sad: the traditional (but unnecessary) space
	// in a self-closing tagColor requires a second test of printedProps.

	exports.printComment = printComment;

	const printElement = (
	  type,
	  printedProps,
	  printedChildren,
	  config,
	  indentation
	) => {
	  const tagColor = config.colors.tag;
	  return (
	    tagColor.open +
	    '<' +
	    type +
	    (printedProps &&
	      tagColor.close +
	        printedProps +
	        config.spacingOuter +
	        indentation +
	        tagColor.open) +
	    (printedChildren
	      ? '>' +
	        tagColor.close +
	        printedChildren +
	        config.spacingOuter +
	        indentation +
	        tagColor.open +
	        '</' +
	        type
	      : (printedProps && !config.min ? '' : ' ') + '/') +
	    '>' +
	    tagColor.close
	  );
	};

	exports.printElement = printElement;

	const printElementAsLeaf = (type, config) => {
	  const tagColor = config.colors.tag;
	  return (
	    tagColor.open +
	    '<' +
	    type +
	    tagColor.close +
	    ' …' +
	    tagColor.open +
	    ' />' +
	    tagColor.close
	  );
	};

	exports.printElementAsLeaf = printElementAsLeaf;
	});

	unwrapExports(markup);
	var markup_1 = markup.printElementAsLeaf;
	var markup_2 = markup.printElement;
	var markup_3 = markup.printComment;
	var markup_4 = markup.printText;
	var markup_5 = markup.printChildren;
	var markup_6 = markup.printProps;

	var DOMElement = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = exports.serialize = exports.test = void 0;



	/**
	 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
	 *
	 * This source code is licensed under the MIT license found in the
	 * LICENSE file in the root directory of this source tree.
	 */
	const ELEMENT_NODE = 1;
	const TEXT_NODE = 3;
	const COMMENT_NODE = 8;
	const FRAGMENT_NODE = 11;
	const ELEMENT_REGEXP = /^((HTML|SVG)\w*)?Element$/;

	const testNode = (nodeType, name) =>
	  (nodeType === ELEMENT_NODE && ELEMENT_REGEXP.test(name)) ||
	  (nodeType === TEXT_NODE && name === 'Text') ||
	  (nodeType === COMMENT_NODE && name === 'Comment') ||
	  (nodeType === FRAGMENT_NODE && name === 'DocumentFragment');

	const test = val =>
	  val &&
	  val.constructor &&
	  val.constructor.name &&
	  testNode(val.nodeType, val.constructor.name);

	exports.test = test;

	function nodeIsText(node) {
	  return node.nodeType === TEXT_NODE;
	}

	function nodeIsComment(node) {
	  return node.nodeType === COMMENT_NODE;
	}

	function nodeIsFragment(node) {
	  return node.nodeType === FRAGMENT_NODE;
	}

	const serialize = (node, config, indentation, depth, refs, printer) => {
	  if (nodeIsText(node)) {
	    return (0, markup.printText)(node.data, config);
	  }

	  if (nodeIsComment(node)) {
	    return (0, markup.printComment)(node.data, config);
	  }

	  const type = nodeIsFragment(node)
	    ? `DocumentFragment`
	    : node.tagName.toLowerCase();

	  if (++depth > config.maxDepth) {
	    return (0, markup.printElementAsLeaf)(type, config);
	  }

	  return (0, markup.printElement)(
	    type,
	    (0, markup.printProps)(
	      nodeIsFragment(node)
	        ? []
	        : Array.from(node.attributes)
	            .map(attr => attr.name)
	            .sort(),
	      nodeIsFragment(node)
	        ? []
	        : Array.from(node.attributes).reduce((props, attribute) => {
	            props[attribute.name] = attribute.value;
	            return props;
	          }, {}),
	      config,
	      indentation + config.indent,
	      depth,
	      refs,
	      printer
	    ),
	    (0, markup.printChildren)(
	      Array.prototype.slice.call(node.childNodes || node.children),
	      config,
	      indentation + config.indent,
	      depth,
	      refs,
	      printer
	    ),
	    config,
	    indentation
	  );
	};

	exports.serialize = serialize;
	const plugin = {
	  serialize,
	  test
	};
	var _default = plugin;
	exports.default = _default;
	});

	unwrapExports(DOMElement);
	var DOMElement_1 = DOMElement.serialize;
	var DOMElement_2 = DOMElement.test;

	var Immutable = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = exports.test = exports.serialize = void 0;



	/**
	 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
	 *
	 * This source code is licensed under the MIT license found in the
	 * LICENSE file in the root directory of this source tree.
	 */
	// SENTINEL constants are from https://github.com/facebook/immutable-js
	const IS_ITERABLE_SENTINEL = '@@__IMMUTABLE_ITERABLE__@@';
	const IS_LIST_SENTINEL = '@@__IMMUTABLE_LIST__@@';
	const IS_KEYED_SENTINEL = '@@__IMMUTABLE_KEYED__@@';
	const IS_MAP_SENTINEL = '@@__IMMUTABLE_MAP__@@';
	const IS_ORDERED_SENTINEL = '@@__IMMUTABLE_ORDERED__@@';
	const IS_RECORD_SENTINEL = '@@__IMMUTABLE_RECORD__@@'; // immutable v4

	const IS_SEQ_SENTINEL = '@@__IMMUTABLE_SEQ__@@';
	const IS_SET_SENTINEL = '@@__IMMUTABLE_SET__@@';
	const IS_STACK_SENTINEL = '@@__IMMUTABLE_STACK__@@';

	const getImmutableName = name => 'Immutable.' + name;

	const printAsLeaf = name => '[' + name + ']';

	const SPACE = ' ';
	const LAZY = '…'; // Seq is lazy if it calls a method like filter

	const printImmutableEntries = (
	  val,
	  config,
	  indentation,
	  depth,
	  refs,
	  printer,
	  type
	) =>
	  ++depth > config.maxDepth
	    ? printAsLeaf(getImmutableName(type))
	    : getImmutableName(type) +
	      SPACE +
	      '{' +
	      (0, collections.printIteratorEntries)(
	        val.entries(),
	        config,
	        indentation,
	        depth,
	        refs,
	        printer
	      ) +
	      '}'; // Record has an entries method because it is a collection in immutable v3.
	// Return an iterator for Immutable Record from version v3 or v4.

	const getRecordEntries = val => {
	  let i = 0;
	  return {
	    next() {
	      if (i < val._keys.length) {
	        const key = val._keys[i++];
	        return {
	          done: false,
	          value: [key, val.get(key)]
	        };
	      }

	      return {
	        done: true
	      };
	    }
	  };
	};

	const printImmutableRecord = (
	  val,
	  config,
	  indentation,
	  depth,
	  refs,
	  printer
	) => {
	  // _name property is defined only for an Immutable Record instance
	  // which was constructed with a second optional descriptive name arg
	  const name = getImmutableName(val._name || 'Record');
	  return ++depth > config.maxDepth
	    ? printAsLeaf(name)
	    : name +
	        SPACE +
	        '{' +
	        (0, collections.printIteratorEntries)(
	          getRecordEntries(val),
	          config,
	          indentation,
	          depth,
	          refs,
	          printer
	        ) +
	        '}';
	};

	const printImmutableSeq = (val, config, indentation, depth, refs, printer) => {
	  const name = getImmutableName('Seq');

	  if (++depth > config.maxDepth) {
	    return printAsLeaf(name);
	  }

	  if (val[IS_KEYED_SENTINEL]) {
	    return (
	      name +
	      SPACE +
	      '{' + // from Immutable collection of entries or from ECMAScript object
	      (val._iter || val._object
	        ? (0, collections.printIteratorEntries)(
	            val.entries(),
	            config,
	            indentation,
	            depth,
	            refs,
	            printer
	          )
	        : LAZY) +
	      '}'
	    );
	  }

	  return (
	    name +
	    SPACE +
	    '[' +
	    (val._iter || // from Immutable collection of values
	    val._array || // from ECMAScript array
	    val._collection || // from ECMAScript collection in immutable v4
	    val._iterable // from ECMAScript collection in immutable v3
	      ? (0, collections.printIteratorValues)(
	          val.values(),
	          config,
	          indentation,
	          depth,
	          refs,
	          printer
	        )
	      : LAZY) +
	    ']'
	  );
	};

	const printImmutableValues = (
	  val,
	  config,
	  indentation,
	  depth,
	  refs,
	  printer,
	  type
	) =>
	  ++depth > config.maxDepth
	    ? printAsLeaf(getImmutableName(type))
	    : getImmutableName(type) +
	      SPACE +
	      '[' +
	      (0, collections.printIteratorValues)(
	        val.values(),
	        config,
	        indentation,
	        depth,
	        refs,
	        printer
	      ) +
	      ']';

	const serialize = (val, config, indentation, depth, refs, printer) => {
	  if (val[IS_MAP_SENTINEL]) {
	    return printImmutableEntries(
	      val,
	      config,
	      indentation,
	      depth,
	      refs,
	      printer,
	      val[IS_ORDERED_SENTINEL] ? 'OrderedMap' : 'Map'
	    );
	  }

	  if (val[IS_LIST_SENTINEL]) {
	    return printImmutableValues(
	      val,
	      config,
	      indentation,
	      depth,
	      refs,
	      printer,
	      'List'
	    );
	  }

	  if (val[IS_SET_SENTINEL]) {
	    return printImmutableValues(
	      val,
	      config,
	      indentation,
	      depth,
	      refs,
	      printer,
	      val[IS_ORDERED_SENTINEL] ? 'OrderedSet' : 'Set'
	    );
	  }

	  if (val[IS_STACK_SENTINEL]) {
	    return printImmutableValues(
	      val,
	      config,
	      indentation,
	      depth,
	      refs,
	      printer,
	      'Stack'
	    );
	  }

	  if (val[IS_SEQ_SENTINEL]) {
	    return printImmutableSeq(val, config, indentation, depth, refs, printer);
	  } // For compatibility with immutable v3 and v4, let record be the default.

	  return printImmutableRecord(val, config, indentation, depth, refs, printer);
	}; // Explicitly comparing sentinel properties to true avoids false positive
	// when mock identity-obj-proxy returns the key as the value for any key.

	exports.serialize = serialize;

	const test = val =>
	  val &&
	  (val[IS_ITERABLE_SENTINEL] === true || val[IS_RECORD_SENTINEL] === true);

	exports.test = test;
	const plugin = {
	  serialize,
	  test
	};
	var _default = plugin;
	exports.default = _default;
	});

	unwrapExports(Immutable);
	var Immutable_1 = Immutable.test;
	var Immutable_2 = Immutable.serialize;

	var reactIs_production_min = createCommonjsModule(function (module, exports) {
	Object.defineProperty(exports,"__esModule",{value:!0});
	var b="function"===typeof Symbol&&Symbol.for,c=b?Symbol.for("react.element"):60103,d=b?Symbol.for("react.portal"):60106,e=b?Symbol.for("react.fragment"):60107,f=b?Symbol.for("react.strict_mode"):60108,g=b?Symbol.for("react.profiler"):60114,h=b?Symbol.for("react.provider"):60109,k=b?Symbol.for("react.context"):60110,l=b?Symbol.for("react.async_mode"):60111,m=b?Symbol.for("react.concurrent_mode"):60111,n=b?Symbol.for("react.forward_ref"):60112,p=b?Symbol.for("react.suspense"):60113,q=b?Symbol.for("react.memo"):
	60115,r=b?Symbol.for("react.lazy"):60116;function t(a){if("object"===typeof a&&null!==a){var u=a.$$typeof;switch(u){case c:switch(a=a.type,a){case l:case m:case e:case g:case f:case p:return a;default:switch(a=a&&a.$$typeof,a){case k:case n:case h:return a;default:return u}}case r:case q:case d:return u}}}function v(a){return t(a)===m}exports.typeOf=t;exports.AsyncMode=l;exports.ConcurrentMode=m;exports.ContextConsumer=k;exports.ContextProvider=h;exports.Element=c;exports.ForwardRef=n;
	exports.Fragment=e;exports.Lazy=r;exports.Memo=q;exports.Portal=d;exports.Profiler=g;exports.StrictMode=f;exports.Suspense=p;exports.isValidElementType=function(a){return "string"===typeof a||"function"===typeof a||a===e||a===m||a===g||a===f||a===p||"object"===typeof a&&null!==a&&(a.$$typeof===r||a.$$typeof===q||a.$$typeof===h||a.$$typeof===k||a.$$typeof===n)};exports.isAsyncMode=function(a){return v(a)||t(a)===l};exports.isConcurrentMode=v;exports.isContextConsumer=function(a){return t(a)===k};
	exports.isContextProvider=function(a){return t(a)===h};exports.isElement=function(a){return "object"===typeof a&&null!==a&&a.$$typeof===c};exports.isForwardRef=function(a){return t(a)===n};exports.isFragment=function(a){return t(a)===e};exports.isLazy=function(a){return t(a)===r};exports.isMemo=function(a){return t(a)===q};exports.isPortal=function(a){return t(a)===d};exports.isProfiler=function(a){return t(a)===g};exports.isStrictMode=function(a){return t(a)===f};
	exports.isSuspense=function(a){return t(a)===p};
	});

	unwrapExports(reactIs_production_min);
	var reactIs_production_min_1 = reactIs_production_min.typeOf;
	var reactIs_production_min_2 = reactIs_production_min.AsyncMode;
	var reactIs_production_min_3 = reactIs_production_min.ConcurrentMode;
	var reactIs_production_min_4 = reactIs_production_min.ContextConsumer;
	var reactIs_production_min_5 = reactIs_production_min.ContextProvider;
	var reactIs_production_min_6 = reactIs_production_min.Element;
	var reactIs_production_min_7 = reactIs_production_min.ForwardRef;
	var reactIs_production_min_8 = reactIs_production_min.Fragment;
	var reactIs_production_min_9 = reactIs_production_min.Lazy;
	var reactIs_production_min_10 = reactIs_production_min.Memo;
	var reactIs_production_min_11 = reactIs_production_min.Portal;
	var reactIs_production_min_12 = reactIs_production_min.Profiler;
	var reactIs_production_min_13 = reactIs_production_min.StrictMode;
	var reactIs_production_min_14 = reactIs_production_min.Suspense;
	var reactIs_production_min_15 = reactIs_production_min.isValidElementType;
	var reactIs_production_min_16 = reactIs_production_min.isAsyncMode;
	var reactIs_production_min_17 = reactIs_production_min.isConcurrentMode;
	var reactIs_production_min_18 = reactIs_production_min.isContextConsumer;
	var reactIs_production_min_19 = reactIs_production_min.isContextProvider;
	var reactIs_production_min_20 = reactIs_production_min.isElement;
	var reactIs_production_min_21 = reactIs_production_min.isForwardRef;
	var reactIs_production_min_22 = reactIs_production_min.isFragment;
	var reactIs_production_min_23 = reactIs_production_min.isLazy;
	var reactIs_production_min_24 = reactIs_production_min.isMemo;
	var reactIs_production_min_25 = reactIs_production_min.isPortal;
	var reactIs_production_min_26 = reactIs_production_min.isProfiler;
	var reactIs_production_min_27 = reactIs_production_min.isStrictMode;
	var reactIs_production_min_28 = reactIs_production_min.isSuspense;

	var reactIs_development = createCommonjsModule(function (module, exports) {



	{
	  (function() {

	Object.defineProperty(exports, '__esModule', { value: true });

	// The Symbol used to tag the ReactElement-like types. If there is no native Symbol
	// nor polyfill, then a plain number is used for performance.
	var hasSymbol = typeof Symbol === 'function' && Symbol.for;

	var REACT_ELEMENT_TYPE = hasSymbol ? Symbol.for('react.element') : 0xeac7;
	var REACT_PORTAL_TYPE = hasSymbol ? Symbol.for('react.portal') : 0xeaca;
	var REACT_FRAGMENT_TYPE = hasSymbol ? Symbol.for('react.fragment') : 0xeacb;
	var REACT_STRICT_MODE_TYPE = hasSymbol ? Symbol.for('react.strict_mode') : 0xeacc;
	var REACT_PROFILER_TYPE = hasSymbol ? Symbol.for('react.profiler') : 0xead2;
	var REACT_PROVIDER_TYPE = hasSymbol ? Symbol.for('react.provider') : 0xeacd;
	var REACT_CONTEXT_TYPE = hasSymbol ? Symbol.for('react.context') : 0xeace;
	var REACT_ASYNC_MODE_TYPE = hasSymbol ? Symbol.for('react.async_mode') : 0xeacf;
	var REACT_CONCURRENT_MODE_TYPE = hasSymbol ? Symbol.for('react.concurrent_mode') : 0xeacf;
	var REACT_FORWARD_REF_TYPE = hasSymbol ? Symbol.for('react.forward_ref') : 0xead0;
	var REACT_SUSPENSE_TYPE = hasSymbol ? Symbol.for('react.suspense') : 0xead1;
	var REACT_MEMO_TYPE = hasSymbol ? Symbol.for('react.memo') : 0xead3;
	var REACT_LAZY_TYPE = hasSymbol ? Symbol.for('react.lazy') : 0xead4;

	function isValidElementType(type) {
	  return typeof type === 'string' || typeof type === 'function' ||
	  // Note: its typeof might be other than 'symbol' or 'number' if it's a polyfill.
	  type === REACT_FRAGMENT_TYPE || type === REACT_CONCURRENT_MODE_TYPE || type === REACT_PROFILER_TYPE || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || typeof type === 'object' && type !== null && (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE);
	}

	/**
	 * Forked from fbjs/warning:
	 * https://github.com/facebook/fbjs/blob/e66ba20ad5be433eb54423f2b097d829324d9de6/packages/fbjs/src/__forks__/warning.js
	 *
	 * Only change is we use console.warn instead of console.error,
	 * and do nothing when 'console' is not supported.
	 * This really simplifies the code.
	 * ---
	 * Similar to invariant but only logs a warning if the condition is not met.
	 * This can be used to log issues in development environments in critical
	 * paths. Removing the logging code for production environments will keep the
	 * same logic and follow the same code paths.
	 */

	var lowPriorityWarning = function () {};

	{
	  var printWarning = function (format) {
	    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
	      args[_key - 1] = arguments[_key];
	    }

	    var argIndex = 0;
	    var message = 'Warning: ' + format.replace(/%s/g, function () {
	      return args[argIndex++];
	    });
	    if (typeof console !== 'undefined') {
	      console.warn(message);
	    }
	    try {
	      // --- Welcome to debugging React ---
	      // This error was thrown as a convenience so that you can use this stack
	      // to find the callsite that caused this warning to fire.
	      throw new Error(message);
	    } catch (x) {}
	  };

	  lowPriorityWarning = function (condition, format) {
	    if (format === undefined) {
	      throw new Error('`lowPriorityWarning(condition, format, ...args)` requires a warning ' + 'message argument');
	    }
	    if (!condition) {
	      for (var _len2 = arguments.length, args = Array(_len2 > 2 ? _len2 - 2 : 0), _key2 = 2; _key2 < _len2; _key2++) {
	        args[_key2 - 2] = arguments[_key2];
	      }

	      printWarning.apply(undefined, [format].concat(args));
	    }
	  };
	}

	var lowPriorityWarning$1 = lowPriorityWarning;

	function typeOf(object) {
	  if (typeof object === 'object' && object !== null) {
	    var $$typeof = object.$$typeof;
	    switch ($$typeof) {
	      case REACT_ELEMENT_TYPE:
	        var type = object.type;

	        switch (type) {
	          case REACT_ASYNC_MODE_TYPE:
	          case REACT_CONCURRENT_MODE_TYPE:
	          case REACT_FRAGMENT_TYPE:
	          case REACT_PROFILER_TYPE:
	          case REACT_STRICT_MODE_TYPE:
	          case REACT_SUSPENSE_TYPE:
	            return type;
	          default:
	            var $$typeofType = type && type.$$typeof;

	            switch ($$typeofType) {
	              case REACT_CONTEXT_TYPE:
	              case REACT_FORWARD_REF_TYPE:
	              case REACT_PROVIDER_TYPE:
	                return $$typeofType;
	              default:
	                return $$typeof;
	            }
	        }
	      case REACT_LAZY_TYPE:
	      case REACT_MEMO_TYPE:
	      case REACT_PORTAL_TYPE:
	        return $$typeof;
	    }
	  }

	  return undefined;
	}

	// AsyncMode is deprecated along with isAsyncMode
	var AsyncMode = REACT_ASYNC_MODE_TYPE;
	var ConcurrentMode = REACT_CONCURRENT_MODE_TYPE;
	var ContextConsumer = REACT_CONTEXT_TYPE;
	var ContextProvider = REACT_PROVIDER_TYPE;
	var Element = REACT_ELEMENT_TYPE;
	var ForwardRef = REACT_FORWARD_REF_TYPE;
	var Fragment = REACT_FRAGMENT_TYPE;
	var Lazy = REACT_LAZY_TYPE;
	var Memo = REACT_MEMO_TYPE;
	var Portal = REACT_PORTAL_TYPE;
	var Profiler = REACT_PROFILER_TYPE;
	var StrictMode = REACT_STRICT_MODE_TYPE;
	var Suspense = REACT_SUSPENSE_TYPE;

	var hasWarnedAboutDeprecatedIsAsyncMode = false;

	// AsyncMode should be deprecated
	function isAsyncMode(object) {
	  {
	    if (!hasWarnedAboutDeprecatedIsAsyncMode) {
	      hasWarnedAboutDeprecatedIsAsyncMode = true;
	      lowPriorityWarning$1(false, 'The ReactIs.isAsyncMode() alias has been deprecated, ' + 'and will be removed in React 17+. Update your code to use ' + 'ReactIs.isConcurrentMode() instead. It has the exact same API.');
	    }
	  }
	  return isConcurrentMode(object) || typeOf(object) === REACT_ASYNC_MODE_TYPE;
	}
	function isConcurrentMode(object) {
	  return typeOf(object) === REACT_CONCURRENT_MODE_TYPE;
	}
	function isContextConsumer(object) {
	  return typeOf(object) === REACT_CONTEXT_TYPE;
	}
	function isContextProvider(object) {
	  return typeOf(object) === REACT_PROVIDER_TYPE;
	}
	function isElement(object) {
	  return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;
	}
	function isForwardRef(object) {
	  return typeOf(object) === REACT_FORWARD_REF_TYPE;
	}
	function isFragment(object) {
	  return typeOf(object) === REACT_FRAGMENT_TYPE;
	}
	function isLazy(object) {
	  return typeOf(object) === REACT_LAZY_TYPE;
	}
	function isMemo(object) {
	  return typeOf(object) === REACT_MEMO_TYPE;
	}
	function isPortal(object) {
	  return typeOf(object) === REACT_PORTAL_TYPE;
	}
	function isProfiler(object) {
	  return typeOf(object) === REACT_PROFILER_TYPE;
	}
	function isStrictMode(object) {
	  return typeOf(object) === REACT_STRICT_MODE_TYPE;
	}
	function isSuspense(object) {
	  return typeOf(object) === REACT_SUSPENSE_TYPE;
	}

	exports.typeOf = typeOf;
	exports.AsyncMode = AsyncMode;
	exports.ConcurrentMode = ConcurrentMode;
	exports.ContextConsumer = ContextConsumer;
	exports.ContextProvider = ContextProvider;
	exports.Element = Element;
	exports.ForwardRef = ForwardRef;
	exports.Fragment = Fragment;
	exports.Lazy = Lazy;
	exports.Memo = Memo;
	exports.Portal = Portal;
	exports.Profiler = Profiler;
	exports.StrictMode = StrictMode;
	exports.Suspense = Suspense;
	exports.isValidElementType = isValidElementType;
	exports.isAsyncMode = isAsyncMode;
	exports.isConcurrentMode = isConcurrentMode;
	exports.isContextConsumer = isContextConsumer;
	exports.isContextProvider = isContextProvider;
	exports.isElement = isElement;
	exports.isForwardRef = isForwardRef;
	exports.isFragment = isFragment;
	exports.isLazy = isLazy;
	exports.isMemo = isMemo;
	exports.isPortal = isPortal;
	exports.isProfiler = isProfiler;
	exports.isStrictMode = isStrictMode;
	exports.isSuspense = isSuspense;
	  })();
	}
	});

	unwrapExports(reactIs_development);
	var reactIs_development_1 = reactIs_development.typeOf;
	var reactIs_development_2 = reactIs_development.AsyncMode;
	var reactIs_development_3 = reactIs_development.ConcurrentMode;
	var reactIs_development_4 = reactIs_development.ContextConsumer;
	var reactIs_development_5 = reactIs_development.ContextProvider;
	var reactIs_development_6 = reactIs_development.Element;
	var reactIs_development_7 = reactIs_development.ForwardRef;
	var reactIs_development_8 = reactIs_development.Fragment;
	var reactIs_development_9 = reactIs_development.Lazy;
	var reactIs_development_10 = reactIs_development.Memo;
	var reactIs_development_11 = reactIs_development.Portal;
	var reactIs_development_12 = reactIs_development.Profiler;
	var reactIs_development_13 = reactIs_development.StrictMode;
	var reactIs_development_14 = reactIs_development.Suspense;
	var reactIs_development_15 = reactIs_development.isValidElementType;
	var reactIs_development_16 = reactIs_development.isAsyncMode;
	var reactIs_development_17 = reactIs_development.isConcurrentMode;
	var reactIs_development_18 = reactIs_development.isContextConsumer;
	var reactIs_development_19 = reactIs_development.isContextProvider;
	var reactIs_development_20 = reactIs_development.isElement;
	var reactIs_development_21 = reactIs_development.isForwardRef;
	var reactIs_development_22 = reactIs_development.isFragment;
	var reactIs_development_23 = reactIs_development.isLazy;
	var reactIs_development_24 = reactIs_development.isMemo;
	var reactIs_development_25 = reactIs_development.isPortal;
	var reactIs_development_26 = reactIs_development.isProfiler;
	var reactIs_development_27 = reactIs_development.isStrictMode;
	var reactIs_development_28 = reactIs_development.isSuspense;

	var reactIs = createCommonjsModule(function (module) {

	{
	  module.exports = reactIs_development;
	}
	});

	var ReactElement = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = exports.test = exports.serialize = void 0;

	var ReactIs = _interopRequireWildcard(reactIs);



	function _interopRequireWildcard(obj) {
	  if (obj && obj.__esModule) {
	    return obj;
	  } else {
	    var newObj = {};
	    if (obj != null) {
	      for (var key in obj) {
	        if (Object.prototype.hasOwnProperty.call(obj, key)) {
	          var desc =
	            Object.defineProperty && Object.getOwnPropertyDescriptor
	              ? Object.getOwnPropertyDescriptor(obj, key)
	              : {};
	          if (desc.get || desc.set) {
	            Object.defineProperty(newObj, key, desc);
	          } else {
	            newObj[key] = obj[key];
	          }
	        }
	      }
	    }
	    newObj.default = obj;
	    return newObj;
	  }
	}

	/**
	 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
	 *
	 * This source code is licensed under the MIT license found in the
	 * LICENSE file in the root directory of this source tree.
	 */
	// Given element.props.children, or subtree during recursive traversal,
	// return flattened array of children.
	const getChildren = (arg, children = []) => {
	  if (Array.isArray(arg)) {
	    arg.forEach(item => {
	      getChildren(item, children);
	    });
	  } else if (arg != null && arg !== false) {
	    children.push(arg);
	  }

	  return children;
	};

	const getType = element => {
	  const type = element.type;

	  if (typeof type === 'string') {
	    return type;
	  }

	  if (typeof type === 'function') {
	    return type.displayName || type.name || 'Unknown';
	  }

	  if (ReactIs.isFragment(element)) {
	    return 'React.Fragment';
	  }

	  if (ReactIs.isSuspense(element)) {
	    return 'React.Suspense';
	  }

	  if (typeof type === 'object' && type !== null) {
	    if (ReactIs.isContextProvider(element)) {
	      return 'Context.Provider';
	    }

	    if (ReactIs.isContextConsumer(element)) {
	      return 'Context.Consumer';
	    }

	    if (ReactIs.isForwardRef(element)) {
	      const functionName = type.render.displayName || type.render.name || '';
	      return functionName !== ''
	        ? 'ForwardRef(' + functionName + ')'
	        : 'ForwardRef';
	    }

	    if (ReactIs.isMemo(type)) {
	      const functionName = type.type.displayName || type.type.name || '';
	      return functionName !== '' ? 'Memo(' + functionName + ')' : 'Memo';
	    }
	  }

	  return 'UNDEFINED';
	};

	const getPropKeys = element => {
	  const props = element.props;
	  return Object.keys(props)
	    .filter(key => key !== 'children' && props[key] !== undefined)
	    .sort();
	};

	const serialize = (element, config, indentation, depth, refs, printer) =>
	  ++depth > config.maxDepth
	    ? (0, markup.printElementAsLeaf)(getType(element), config)
	    : (0, markup.printElement)(
	        getType(element),
	        (0, markup.printProps)(
	          getPropKeys(element),
	          element.props,
	          config,
	          indentation + config.indent,
	          depth,
	          refs,
	          printer
	        ),
	        (0, markup.printChildren)(
	          getChildren(element.props.children),
	          config,
	          indentation + config.indent,
	          depth,
	          refs,
	          printer
	        ),
	        config,
	        indentation
	      );

	exports.serialize = serialize;

	const test = val => val && ReactIs.isElement(val);

	exports.test = test;
	const plugin = {
	  serialize,
	  test
	};
	var _default = plugin;
	exports.default = _default;
	});

	unwrapExports(ReactElement);
	var ReactElement_1 = ReactElement.test;
	var ReactElement_2 = ReactElement.serialize;

	var ReactTestComponent = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, '__esModule', {
	  value: true
	});
	exports.default = exports.test = exports.serialize = void 0;



	var Symbol = commonjsGlobal['jest-symbol-do-not-touch'] || commonjsGlobal.Symbol;
	const testSymbol = Symbol.for('react.test.json');

	const getPropKeys = object => {
	  const props = object.props;
	  return props
	    ? Object.keys(props)
	        .filter(key => props[key] !== undefined)
	        .sort()
	    : [];
	};

	const serialize = (object, config, indentation, depth, refs, printer) =>
	  ++depth > config.maxDepth
	    ? (0, markup.printElementAsLeaf)(object.type, config)
	    : (0, markup.printElement)(
	        object.type,
	        object.props
	          ? (0, markup.printProps)(
	              getPropKeys(object),
	              object.props,
	              config,
	              indentation + config.indent,
	              depth,
	              refs,
	              printer
	            )
	          : '',
	        object.children
	          ? (0, markup.printChildren)(
	              object.children,
	              config,
	              indentation + config.indent,
	              depth,
	              refs,
	              printer
	            )
	          : '',
	        config,
	        indentation
	      );

	exports.serialize = serialize;

	const test = val => val && val.$$typeof === testSymbol;

	exports.test = test;
	const plugin = {
	  serialize,
	  test
	};
	var _default = plugin;
	exports.default = _default;
	});

	unwrapExports(ReactTestComponent);
	var ReactTestComponent_1 = ReactTestComponent.test;
	var ReactTestComponent_2 = ReactTestComponent.serialize;

	var build = createCommonjsModule(function (module) {

	var _ansiStyles = _interopRequireDefault(ansiStyles);



	var _AsymmetricMatcher = _interopRequireDefault(
	  AsymmetricMatcher
	);

	var _ConvertAnsi = _interopRequireDefault(ConvertAnsi);

	var _DOMCollection = _interopRequireDefault(DOMCollection);

	var _DOMElement = _interopRequireDefault(DOMElement);

	var _Immutable = _interopRequireDefault(Immutable);

	var _ReactElement = _interopRequireDefault(ReactElement);

	var _ReactTestComponent = _interopRequireDefault(
	  ReactTestComponent
	);

	function _interopRequireDefault(obj) {
	  return obj && obj.__esModule ? obj : {default: obj};
	}

	var Symbol = commonjsGlobal['jest-symbol-do-not-touch'] || commonjsGlobal.Symbol;
	const toString = Object.prototype.toString;
	const toISOString = Date.prototype.toISOString;
	const errorToString = Error.prototype.toString;
	const regExpToString = RegExp.prototype.toString;
	const symbolToString = Symbol.prototype.toString;
	/**
	 * Explicitly comparing typeof constructor to function avoids undefined as name
	 * when mock identity-obj-proxy returns the key as the value for any key.
	 */

	const getConstructorName = val =>
	  (typeof val.constructor === 'function' && val.constructor.name) || 'Object';
	/* global window */

	/** Is val is equal to global window object? Works even if it does not exist :) */

	const isWindow = val => typeof window !== 'undefined' && val === window;

	const SYMBOL_REGEXP = /^Symbol\((.*)\)(.*)$/;
	const NEWLINE_REGEXP = /\n/gi;

	class PrettyFormatPluginError extends Error {
	  constructor(message, stack) {
	    super(message);
	    this.stack = stack;
	    this.name = this.constructor.name;
	  }
	}

	function isToStringedArrayType(toStringed) {
	  return (
	    toStringed === '[object Array]' ||
	    toStringed === '[object ArrayBuffer]' ||
	    toStringed === '[object DataView]' ||
	    toStringed === '[object Float32Array]' ||
	    toStringed === '[object Float64Array]' ||
	    toStringed === '[object Int8Array]' ||
	    toStringed === '[object Int16Array]' ||
	    toStringed === '[object Int32Array]' ||
	    toStringed === '[object Uint8Array]' ||
	    toStringed === '[object Uint8ClampedArray]' ||
	    toStringed === '[object Uint16Array]' ||
	    toStringed === '[object Uint32Array]'
	  );
	}

	function printNumber(val) {
	  return Object.is(val, -0) ? '-0' : String(val);
	}

	function printBigInt(val) {
	  return String(`${val}n`);
	}

	function printFunction(val, printFunctionName) {
	  if (!printFunctionName) {
	    return '[Function]';
	  }

	  return '[Function ' + (val.name || 'anonymous') + ']';
	}

	function printSymbol(val) {
	  return symbolToString.call(val).replace(SYMBOL_REGEXP, 'Symbol($1)');
	}

	function printError(val) {
	  return '[' + errorToString.call(val) + ']';
	}
	/**
	 * The first port of call for printing an object, handles most of the
	 * data-types in JS.
	 */

	function printBasicValue(val, printFunctionName, escapeRegex, escapeString) {
	  if (val === true || val === false) {
	    return '' + val;
	  }

	  if (val === undefined) {
	    return 'undefined';
	  }

	  if (val === null) {
	    return 'null';
	  }

	  const typeOf = typeof val;

	  if (typeOf === 'number') {
	    return printNumber(val);
	  }

	  if (typeOf === 'bigint') {
	    return printBigInt(val);
	  }

	  if (typeOf === 'string') {
	    if (escapeString) {
	      return '"' + val.replace(/"|\\/g, '\\$&') + '"';
	    }

	    return '"' + val + '"';
	  }

	  if (typeOf === 'function') {
	    return printFunction(val, printFunctionName);
	  }

	  if (typeOf === 'symbol') {
	    return printSymbol(val);
	  }

	  const toStringed = toString.call(val);

	  if (toStringed === '[object WeakMap]') {
	    return 'WeakMap {}';
	  }

	  if (toStringed === '[object WeakSet]') {
	    return 'WeakSet {}';
	  }

	  if (
	    toStringed === '[object Function]' ||
	    toStringed === '[object GeneratorFunction]'
	  ) {
	    return printFunction(val, printFunctionName);
	  }

	  if (toStringed === '[object Symbol]') {
	    return printSymbol(val);
	  }

	  if (toStringed === '[object Date]') {
	    return isNaN(+val) ? 'Date { NaN }' : toISOString.call(val);
	  }

	  if (toStringed === '[object Error]') {
	    return printError(val);
	  }

	  if (toStringed === '[object RegExp]') {
	    if (escapeRegex) {
	      // https://github.com/benjamingr/RegExp.escape/blob/master/polyfill.js
	      return regExpToString.call(val).replace(/[\\^$*+?.()|[\]{}]/g, '\\$&');
	    }

	    return regExpToString.call(val);
	  }

	  if (val instanceof Error) {
	    return printError(val);
	  }

	  return null;
	}
	/**
	 * Handles more complex objects ( such as objects with circular references.
	 * maps and sets etc )
	 */

	function printComplexValue(
	  val,
	  config,
	  indentation,
	  depth,
	  refs,
	  hasCalledToJSON
	) {
	  if (refs.indexOf(val) !== -1) {
	    return '[Circular]';
	  }

	  refs = refs.slice();
	  refs.push(val);
	  const hitMaxDepth = ++depth > config.maxDepth;
	  const min = config.min;

	  if (
	    config.callToJSON &&
	    !hitMaxDepth &&
	    val.toJSON &&
	    typeof val.toJSON === 'function' &&
	    !hasCalledToJSON
	  ) {
	    return printer(val.toJSON(), config, indentation, depth, refs, true);
	  }

	  const toStringed = toString.call(val);

	  if (toStringed === '[object Arguments]') {
	    return hitMaxDepth
	      ? '[Arguments]'
	      : (min ? '' : 'Arguments ') +
	          '[' +
	          (0, collections.printListItems)(
	            val,
	            config,
	            indentation,
	            depth,
	            refs,
	            printer
	          ) +
	          ']';
	  }

	  if (isToStringedArrayType(toStringed)) {
	    return hitMaxDepth
	      ? '[' + val.constructor.name + ']'
	      : (min ? '' : val.constructor.name + ' ') +
	          '[' +
	          (0, collections.printListItems)(
	            val,
	            config,
	            indentation,
	            depth,
	            refs,
	            printer
	          ) +
	          ']';
	  }

	  if (toStringed === '[object Map]') {
	    return hitMaxDepth
	      ? '[Map]'
	      : 'Map {' +
	          (0, collections.printIteratorEntries)(
	            val.entries(),
	            config,
	            indentation,
	            depth,
	            refs,
	            printer,
	            ' => '
	          ) +
	          '}';
	  }

	  if (toStringed === '[object Set]') {
	    return hitMaxDepth
	      ? '[Set]'
	      : 'Set {' +
	          (0, collections.printIteratorValues)(
	            val.values(),
	            config,
	            indentation,
	            depth,
	            refs,
	            printer
	          ) +
	          '}';
	  } // Avoid failure to serialize global window object in jsdom test environment.
	  // For example, not even relevant if window is prop of React element.

	  return hitMaxDepth || isWindow(val)
	    ? '[' + getConstructorName(val) + ']'
	    : (min ? '' : getConstructorName(val) + ' ') +
	        '{' +
	        (0, collections.printObjectProperties)(
	          val,
	          config,
	          indentation,
	          depth,
	          refs,
	          printer
	        ) +
	        '}';
	}

	function isNewPlugin(plugin) {
	  return plugin.serialize != null;
	}

	function printPlugin(plugin, val, config, indentation, depth, refs) {
	  let printed;

	  try {
	    printed = isNewPlugin(plugin)
	      ? plugin.serialize(val, config, indentation, depth, refs, printer)
	      : plugin.print(
	          val,
	          valChild => printer(valChild, config, indentation, depth, refs),
	          str => {
	            const indentationNext = indentation + config.indent;
	            return (
	              indentationNext +
	              str.replace(NEWLINE_REGEXP, '\n' + indentationNext)
	            );
	          },
	          {
	            edgeSpacing: config.spacingOuter,
	            min: config.min,
	            spacing: config.spacingInner
	          },
	          config.colors
	        );
	  } catch (error) {
	    throw new PrettyFormatPluginError(error.message, error.stack);
	  }

	  if (typeof printed !== 'string') {
	    throw new Error(
	      `pretty-format: Plugin must return type "string" but instead returned "${typeof printed}".`
	    );
	  }

	  return printed;
	}

	function findPlugin(plugins, val) {
	  for (let p = 0; p < plugins.length; p++) {
	    try {
	      if (plugins[p].test(val)) {
	        return plugins[p];
	      }
	    } catch (error) {
	      throw new PrettyFormatPluginError(error.message, error.stack);
	    }
	  }

	  return null;
	}

	function printer(val, config, indentation, depth, refs, hasCalledToJSON) {
	  const plugin = findPlugin(config.plugins, val);

	  if (plugin !== null) {
	    return printPlugin(plugin, val, config, indentation, depth, refs);
	  }

	  const basicResult = printBasicValue(
	    val,
	    config.printFunctionName,
	    config.escapeRegex,
	    config.escapeString
	  );

	  if (basicResult !== null) {
	    return basicResult;
	  }

	  return printComplexValue(
	    val,
	    config,
	    indentation,
	    depth,
	    refs,
	    hasCalledToJSON
	  );
	}

	const DEFAULT_THEME = {
	  comment: 'gray',
	  content: 'reset',
	  prop: 'yellow',
	  tag: 'cyan',
	  value: 'green'
	};
	const DEFAULT_THEME_KEYS = Object.keys(DEFAULT_THEME);
	const DEFAULT_OPTIONS = {
	  callToJSON: true,
	  escapeRegex: false,
	  escapeString: true,
	  highlight: false,
	  indent: 2,
	  maxDepth: Infinity,
	  min: false,
	  plugins: [],
	  printFunctionName: true,
	  theme: DEFAULT_THEME
	};

	function validateOptions(options) {
	  Object.keys(options).forEach(key => {
	    if (!DEFAULT_OPTIONS.hasOwnProperty(key)) {
	      throw new Error(`pretty-format: Unknown option "${key}".`);
	    }
	  });

	  if (options.min && options.indent !== undefined && options.indent !== 0) {
	    throw new Error(
	      'pretty-format: Options "min" and "indent" cannot be used together.'
	    );
	  }

	  if (options.theme !== undefined) {
	    if (options.theme === null) {
	      throw new Error(`pretty-format: Option "theme" must not be null.`);
	    }

	    if (typeof options.theme !== 'object') {
	      throw new Error(
	        `pretty-format: Option "theme" must be of type "object" but instead received "${typeof options.theme}".`
	      );
	    }
	  }
	}

	const getColorsHighlight = options =>
	  DEFAULT_THEME_KEYS.reduce((colors, key) => {
	    const value =
	      options.theme && options.theme[key] !== undefined
	        ? options.theme[key]
	        : DEFAULT_THEME[key];
	    const color = _ansiStyles.default[value];

	    if (
	      color &&
	      typeof color.close === 'string' &&
	      typeof color.open === 'string'
	    ) {
	      colors[key] = color;
	    } else {
	      throw new Error(
	        `pretty-format: Option "theme" has a key "${key}" whose value "${value}" is undefined in ansi-styles.`
	      );
	    }

	    return colors;
	  }, Object.create(null));

	const getColorsEmpty = () =>
	  DEFAULT_THEME_KEYS.reduce((colors, key) => {
	    colors[key] = {
	      close: '',
	      open: ''
	    };
	    return colors;
	  }, Object.create(null));

	const getPrintFunctionName = options =>
	  options && options.printFunctionName !== undefined
	    ? options.printFunctionName
	    : DEFAULT_OPTIONS.printFunctionName;

	const getEscapeRegex = options =>
	  options && options.escapeRegex !== undefined
	    ? options.escapeRegex
	    : DEFAULT_OPTIONS.escapeRegex;

	const getEscapeString = options =>
	  options && options.escapeString !== undefined
	    ? options.escapeString
	    : DEFAULT_OPTIONS.escapeString;

	const getConfig = options => ({
	  callToJSON:
	    options && options.callToJSON !== undefined
	      ? options.callToJSON
	      : DEFAULT_OPTIONS.callToJSON,
	  colors:
	    options && options.highlight
	      ? getColorsHighlight(options)
	      : getColorsEmpty(),
	  escapeRegex: getEscapeRegex(options),
	  escapeString: getEscapeString(options),
	  indent:
	    options && options.min
	      ? ''
	      : createIndent(
	          options && options.indent !== undefined
	            ? options.indent
	            : DEFAULT_OPTIONS.indent
	        ),
	  maxDepth:
	    options && options.maxDepth !== undefined
	      ? options.maxDepth
	      : DEFAULT_OPTIONS.maxDepth,
	  min: options && options.min !== undefined ? options.min : DEFAULT_OPTIONS.min,
	  plugins:
	    options && options.plugins !== undefined
	      ? options.plugins
	      : DEFAULT_OPTIONS.plugins,
	  printFunctionName: getPrintFunctionName(options),
	  spacingInner: options && options.min ? ' ' : '\n',
	  spacingOuter: options && options.min ? '' : '\n'
	});

	function createIndent(indent) {
	  return new Array(indent + 1).join(' ');
	}
	/**
	 * Returns a presentation string of your `val` object
	 * @param val any potential JavaScript object
	 * @param options Custom settings
	 */

	function prettyFormat(val, options) {
	  if (options) {
	    validateOptions(options);

	    if (options.plugins) {
	      const plugin = findPlugin(options.plugins, val);

	      if (plugin !== null) {
	        return printPlugin(plugin, val, getConfig(options), '', 0, []);
	      }
	    }
	  }

	  const basicResult = printBasicValue(
	    val,
	    getPrintFunctionName(options),
	    getEscapeRegex(options),
	    getEscapeString(options)
	  );

	  if (basicResult !== null) {
	    return basicResult;
	  }

	  return printComplexValue(val, getConfig(options), '', 0, []);
	}

	prettyFormat.plugins = {
	  AsymmetricMatcher: _AsymmetricMatcher.default,
	  ConvertAnsi: _ConvertAnsi.default,
	  DOMCollection: _DOMCollection.default,
	  DOMElement: _DOMElement.default,
	  Immutable: _Immutable.default,
	  ReactElement: _ReactElement.default,
	  ReactTestComponent: _ReactTestComponent.default
	};
	/* eslint-disable-next-line no-redeclare */

	module.exports = prettyFormat;
	});

	unwrapExports(build);

	var prettyDom = createCommonjsModule(function (module, exports) {



	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.prettyDOM = prettyDOM;

	var _extends2 = interopRequireDefault(_extends_1);

	var _prettyFormat = interopRequireDefault(build);

	const {
	  DOMElement,
	  DOMCollection
	} = _prettyFormat.default.plugins;

	function prettyDOM(htmlElement, maxLength, options) {
	  if (htmlElement.documentElement) {
	    htmlElement = htmlElement.documentElement;
	  }

	  const debugContent = (0, _prettyFormat.default)(htmlElement, (0, _extends2.default)({
	    plugins: [DOMElement, DOMCollection],
	    printFunctionName: false,
	    highlight: true
	  }, options));
	  return maxLength !== undefined && htmlElement.outerHTML.length > maxLength ? `${debugContent.slice(0, maxLength)}...` : debugContent;
	}
	});

	unwrapExports(prettyDom);
	var prettyDom_1 = prettyDom.prettyDOM;

	/*!
	 * Shim for MutationObserver interface
	 * Author: Graeme Yeates (github.com/megawac)
	 * Repository: https://github.com/megawac/MutationObserver.js
	 * License: WTFPL V2, 2004 (wtfpl.net).
	 * Though credit and staring the repo will make me feel pretty, you can modify and redistribute as you please.
	 * Attempts to follow spec (https://www.w3.org/TR/dom/#mutation-observers) as closely as possible for native javascript
	 * See https://github.com/WebKit/webkit/blob/master/Source/WebCore/dom/MutationObserver.cpp for current webkit source c++ implementation
	 */

	/**
	 * prefix bugs:
	    - https://bugs.webkit.org/show_bug.cgi?id=85161
	    - https://bugzilla.mozilla.org/show_bug.cgi?id=749920
	 * Don't use WebKitMutationObserver as Safari (6.0.5-6.1) use a buggy implementation
	*/
	var MutationObserver = (function(undefined) {
	    if (typeof window !== 'undefined' && typeof window.MutationObserver !== 'undefined') {
	      return window.MutationObserver
	    }

	    /**
	     * @param {function(Array.<MutationRecord>, MutationObserver)} listener
	     * @constructor
	     */
	    function MutationObserver(listener) {
	        /**
	         * @type {Array.<Object>}
	         * @private
	         */
	        this._watched = [];
	        /** @private */
	        this._listener = listener;
	    }

	    /**
	     * Start a recursive timeout function to check all items being observed for mutations
	     * @type {MutationObserver} observer
	     * @private
	     */
	    function startMutationChecker(observer) {
	        (function check() {
	            var mutations = observer.takeRecords();

	            if (mutations.length) { // fire away
	                // calling the listener with context is not spec but currently consistent with FF and WebKit
	                observer._listener(mutations, observer);
	            }
	            /** @private */
	            observer._timeout = setTimeout(check, MutationObserver._period);
	        })();
	    }

	    /**
	     * Period to check for mutations (~32 times/sec)
	     * @type {number}
	     * @expose
	     */
	    MutationObserver._period = 30 /*ms+runtime*/ ;

	    /**
	     * Exposed API
	     * @expose
	     * @final
	     */
	    MutationObserver.prototype = {
	        /**
	         * see https://dom.spec.whatwg.org/#dom-mutationobserver-observe
	         * not going to throw here but going to follow the current spec config sets
	         * @param {Node|null} $target
	         * @param {Object|null} config : MutationObserverInit configuration dictionary
	         * @expose
	         * @return undefined
	         */
	        observe: function($target, config) {
	            /**
	             * Using slightly different names so closure can go ham
	             * @type {!Object} : A custom mutation config
	             */
	            var settings = {
	                attr: !! (config.attributes || config.attributeFilter || config.attributeOldValue),

	                // some browsers enforce that subtree must be set with childList, attributes or characterData.
	                // We don't care as spec doesn't specify this rule.
	                kids: !! config.childList,
	                descendents: !! config.subtree,
	                charData: !! (config.characterData || config.characterDataOldValue)
	            };

	            var watched = this._watched;

	            // remove already observed target element from pool
	            for (var i = 0; i < watched.length; i++) {
	                if (watched[i].tar === $target) watched.splice(i, 1);
	            }

	            if (config.attributeFilter) {
	                /**
	                 * converts to a {key: true} dict for faster lookup
	                 * @type {Object.<String,Boolean>}
	                 */
	                settings.afilter = reduce(config.attributeFilter, function(a, b) {
	                    a[b] = true;
	                    return a;
	                }, {});
	            }

	            watched.push({
	                tar: $target,
	                fn: createMutationSearcher($target, settings)
	            });

	            // reconnect if not connected
	            if (!this._timeout) {
	                startMutationChecker(this);
	            }
	        },

	        /**
	         * Finds mutations since last check and empties the "record queue" i.e. mutations will only be found once
	         * @expose
	         * @return {Array.<MutationRecord>}
	         */
	        takeRecords: function() {
	            var mutations = [];
	            var watched = this._watched;

	            for (var i = 0; i < watched.length; i++) {
	                watched[i].fn(mutations);
	            }

	            return mutations;
	        },

	        /**
	         * @expose
	         * @return undefined
	         */
	        disconnect: function() {
	            this._watched = []; // clear the stuff being observed
	            clearTimeout(this._timeout); // ready for garbage collection
	            /** @private */
	            this._timeout = null;
	        }
	    };

	    /**
	     * Simple MutationRecord pseudoclass. No longer exposing as its not fully compliant
	     * @param {Object} data
	     * @return {Object} a MutationRecord
	     */
	    function MutationRecord(data) {
	        var settings = { // technically these should be on proto so hasOwnProperty will return false for non explicitly props
	            type: null,
	            target: null,
	            addedNodes: [],
	            removedNodes: [],
	            previousSibling: null,
	            nextSibling: null,
	            attributeName: null,
	            attributeNamespace: null,
	            oldValue: null
	        };
	        for (var prop in data) {
	            if (has(settings, prop) && data[prop] !== undefined) settings[prop] = data[prop];
	        }
	        return settings;
	    }

	    /**
	     * Creates a func to find all the mutations
	     *
	     * @param {Node} $target
	     * @param {!Object} config : A custom mutation config
	     */
	    function createMutationSearcher($target, config) {
	        /** type {Elestuct} */
	        var $oldstate = clone($target, config); // create the cloned datastructure

	        /**
	         * consumes array of mutations we can push to
	         *
	         * @param {Array.<MutationRecord>} mutations
	         */
	        return function(mutations) {
	            var olen = mutations.length, dirty;

	            if (config.charData && $target.nodeType === 3 && $target.nodeValue !== $oldstate.charData) {
	                mutations.push(new MutationRecord({
	                  type: "characterData",
	                  target: $target,
	                  oldValue: $oldstate.charData          
	                }));
	            }

	            // Alright we check base level changes in attributes... easy
	            if (config.attr && $oldstate.attr) {
	                findAttributeMutations(mutations, $target, $oldstate.attr, config.afilter);
	            }

	            // check childlist or subtree for mutations
	            if (config.kids || config.descendents) {
	                dirty = searchSubtree(mutations, $target, $oldstate, config);
	            }

	            // reclone data structure if theres changes
	            if (dirty || mutations.length !== olen) {
	                /** type {Elestuct} */
	                $oldstate = clone($target, config);
	            }
	        };
	    }

	    /* attributes + attributeFilter helpers */

	    // Check if the environment has the attribute bug (#4) which cause
	    // element.attributes.style to always be null.
	    var hasAttributeBug = false;
	    if (typeof document !== 'undefined') {
	      var testElement = document.createElement('i');
	      testElement.style.top = 0;
	      hasAttributeBug = testElement.attributes.style.value != 'null';
	    }

	    /**
	     * Gets an attribute value in an environment without attribute bug
	     *
	     * @param {Node} el
	     * @param {Attr} attr
	     * @return {String} an attribute value
	     */
	    function getAttributeSimple(el, attr) {
	        // There is a potential for a warning to occur here if the attribute is a
	        // custom attribute in IE<9 with a custom .toString() method. This is
	        // just a warning and doesn't affect execution (see #21)
	        return attr.value;
	    }

	    /**
	     * Gets an attribute value with special hack for style attribute (see #4)
	     *
	     * @param {Node} el
	     * @param {Attr} attr
	     * @return {String} an attribute value
	     */
	    function getAttributeWithStyleHack(el, attr) {
	        // As with getAttributeSimple there is a potential warning for custom attribtues in IE7.
	        return attr.name !== "style" ? attr.value : el.style.cssText;
	    }

	    var getAttributeValue = hasAttributeBug ? getAttributeSimple : getAttributeWithStyleHack;

	    /**
	     * fast helper to check to see if attributes object of an element has changed
	     * doesnt handle the textnode case
	     *
	     * @param {Array.<MutationRecord>} mutations
	     * @param {Node} $target
	     * @param {Object.<string, string>} $oldstate : Custom attribute clone data structure from clone
	     * @param {Object} filter
	     */
	    function findAttributeMutations(mutations, $target, $oldstate, filter) {
	        var checked = {};
	        var attributes = $target.attributes;
	        var attr;
	        var name;
	        var i = attributes.length;
	        while (i--) {
	            attr = attributes[i];
	            name = attr.name;
	            if (!filter || has(filter, name)) {
	                if (getAttributeValue($target, attr) !== $oldstate[name]) {
	                    // The pushing is redundant but gzips very nicely
	                    mutations.push(MutationRecord({
	                        type: "attributes",
	                        target: $target,
	                        attributeName: name,
	                        oldValue: $oldstate[name],
	                        attributeNamespace: attr.namespaceURI // in ie<8 it incorrectly will return undefined
	                    }));
	                }
	                checked[name] = true;
	            }
	        }
	        for (name in $oldstate) {
	            if (!(checked[name])) {
	                mutations.push(MutationRecord({
	                    target: $target,
	                    type: "attributes",
	                    attributeName: name,
	                    oldValue: $oldstate[name]
	                }));
	            }
	        }
	    }

	    /**
	     * searchSubtree: array of mutations so far, element, element clone, bool
	     * synchronous dfs comparision of two nodes
	     * This function is applied to any observed element with childList or subtree specified
	     * Sorry this is kind of confusing as shit, tried to comment it a bit...
	     * codereview.stackexchange.com/questions/38351 discussion of an earlier version of this func
	     *
	     * @param {Array} mutations
	     * @param {Node} $target
	     * @param {!Object} $oldstate : A custom cloned node from clone()
	     * @param {!Object} config : A custom mutation config
	     */
	    function searchSubtree(mutations, $target, $oldstate, config) {
	        // Track if the tree is dirty and has to be recomputed (#14).
	        var dirty;
	        /*
	         * Helper to identify node rearrangment and stuff...
	         * There is no gaurentee that the same node will be identified for both added and removed nodes
	         * if the positions have been shuffled.
	         * conflicts array will be emptied by end of operation
	         */
	        function resolveConflicts(conflicts, node, $kids, $oldkids, numAddedNodes) {
	            // the distance between the first conflicting node and the last
	            var distance = conflicts.length - 1;
	            // prevents same conflict being resolved twice consider when two nodes switch places.
	            // only one should be given a mutation event (note -~ is used as a math.ceil shorthand)
	            var counter = -~((distance - numAddedNodes) / 2);
	            var $cur;
	            var oldstruct;
	            var conflict;
	            while ((conflict = conflicts.pop())) {
	                $cur = $kids[conflict.i];
	                oldstruct = $oldkids[conflict.j];

	                // attempt to determine if there was node rearrangement... won't gaurentee all matches
	                // also handles case where added/removed nodes cause nodes to be identified as conflicts
	                if (config.kids && counter && Math.abs(conflict.i - conflict.j) >= distance) {
	                    mutations.push(MutationRecord({
	                        type: "childList",
	                        target: node,
	                        addedNodes: [$cur],
	                        removedNodes: [$cur],
	                        // haha don't rely on this please
	                        nextSibling: $cur.nextSibling,
	                        previousSibling: $cur.previousSibling
	                    }));
	                    counter--; // found conflict
	                }

	                // Alright we found the resorted nodes now check for other types of mutations
	                if (config.attr && oldstruct.attr) findAttributeMutations(mutations, $cur, oldstruct.attr, config.afilter);
	                if (config.charData && $cur.nodeType === 3 && $cur.nodeValue !== oldstruct.charData) {
	                    mutations.push(MutationRecord({
	                        type: "characterData",
	                        target: $cur,
	                        oldValue: oldstruct.charData
	                    }));
	                }
	                // now look @ subtree
	                if (config.descendents) findMutations($cur, oldstruct);
	            }
	        }

	        /**
	         * Main worker. Finds and adds mutations if there are any
	         * @param {Node} node
	         * @param {!Object} old : A cloned data structure using internal clone
	         */
	        function findMutations(node, old) {
	            var $kids = node.childNodes;
	            var $oldkids = old.kids;
	            var klen = $kids.length;
	            // $oldkids will be undefined for text and comment nodes
	            var olen = $oldkids ? $oldkids.length : 0;
	            // if (!olen && !klen) return; // both empty; clearly no changes

	            // we delay the intialization of these for marginal performance in the expected case (actually quite signficant on large subtrees when these would be otherwise unused)
	            // map of checked element of ids to prevent registering the same conflict twice
	            var map;
	            // array of potential conflicts (ie nodes that may have been re arranged)
	            var conflicts;
	            var id; // element id from getElementId helper
	            var idx; // index of a moved or inserted element

	            var oldstruct;
	            // current and old nodes
	            var $cur;
	            var $old;
	            // track the number of added nodes so we can resolve conflicts more accurately
	            var numAddedNodes = 0;

	            // iterate over both old and current child nodes at the same time
	            var i = 0, j = 0;
	            // while there is still anything left in $kids or $oldkids (same as i < $kids.length || j < $oldkids.length;)
	            while( i < klen || j < olen ) {
	                // current and old nodes at the indexs
	                $cur = $kids[i];
	                oldstruct = $oldkids[j];
	                $old = oldstruct && oldstruct.node;

	                if ($cur === $old) { // expected case - optimized for this case
	                    // check attributes as specified by config
	                    if (config.attr && oldstruct.attr) /* oldstruct.attr instead of textnode check */findAttributeMutations(mutations, $cur, oldstruct.attr, config.afilter);
	                    // check character data if node is a comment or textNode and it's being observed
	                    if (config.charData && oldstruct.charData !== undefined && $cur.nodeValue !== oldstruct.charData) {
	                        mutations.push(MutationRecord({
	                            type: "characterData",
	                            target: $cur,
	                            oldValue: oldstruct.charData
	                        }));
	                    }

	                    // resolve conflicts; it will be undefined if there are no conflicts - otherwise an array
	                    if (conflicts) resolveConflicts(conflicts, node, $kids, $oldkids, numAddedNodes);

	                    // recurse on next level of children. Avoids the recursive call when there are no children left to iterate
	                    if (config.descendents && ($cur.childNodes.length || oldstruct.kids && oldstruct.kids.length)) findMutations($cur, oldstruct);

	                    i++;
	                    j++;
	                } else { // (uncommon case) lookahead until they are the same again or the end of children
	                    dirty = true;
	                    if (!map) { // delayed initalization (big perf benefit)
	                        map = {};
	                        conflicts = [];
	                    }
	                    if ($cur) {
	                        // check id is in the location map otherwise do a indexOf search
	                        if (!(map[id = getElementId($cur)])) { // to prevent double checking
	                            // mark id as found
	                            map[id] = true;
	                            // custom indexOf using comparitor checking oldkids[i].node === $cur
	                            if ((idx = indexOfCustomNode($oldkids, $cur, j)) === -1) {
	                                if (config.kids) {
	                                    mutations.push(MutationRecord({
	                                        type: "childList",
	                                        target: node,
	                                        addedNodes: [$cur], // $cur is a new node
	                                        nextSibling: $cur.nextSibling,
	                                        previousSibling: $cur.previousSibling
	                                    }));
	                                    numAddedNodes++;
	                                }
	                            } else {
	                                conflicts.push({ // add conflict
	                                    i: i,
	                                    j: idx
	                                });
	                            }
	                        }
	                        i++;
	                    }

	                    if ($old &&
	                       // special case: the changes may have been resolved: i and j appear congurent so we can continue using the expected case
	                       $old !== $kids[i]
	                    ) {
	                        if (!(map[id = getElementId($old)])) {
	                            map[id] = true;
	                            if ((idx = indexOf($kids, $old, i)) === -1) {
	                                if (config.kids) {
	                                    mutations.push(MutationRecord({
	                                        type: "childList",
	                                        target: old.node,
	                                        removedNodes: [$old],
	                                        nextSibling: $oldkids[j + 1], // praise no indexoutofbounds exception
	                                        previousSibling: $oldkids[j - 1]
	                                    }));
	                                    numAddedNodes--;
	                                }
	                            } else {
	                                conflicts.push({
	                                    i: idx,
	                                    j: j
	                                });
	                            }
	                        }
	                        j++;
	                    }
	                }// end uncommon case
	            }// end loop

	            // resolve any remaining conflicts
	            if (conflicts) resolveConflicts(conflicts, node, $kids, $oldkids, numAddedNodes);
	        }
	        findMutations($target, $oldstate);
	        return dirty;
	    }

	    /**
	     * Utility
	     * Cones a element into a custom data structure designed for comparision. https://gist.github.com/megawac/8201012
	     *
	     * @param {Node} $target
	     * @param {!Object} config : A custom mutation config
	     * @return {!Object} : Cloned data structure
	     */
	    function clone($target, config) {
	        var recurse = true; // set true so childList we'll always check the first level
	        return (function copy($target) {
	            var elestruct = {
	                /** @type {Node} */
	                node: $target
	            };

	            // Store current character data of target text or comment node if the config requests
	            // those properties to be observed.
	            if (config.charData && ($target.nodeType === 3 || $target.nodeType === 8)) {
	                elestruct.charData = $target.nodeValue;
	            }
	            // its either a element, comment, doc frag or document node
	            else {
	                // Add attr only if subtree is specified or top level and avoid if
	                // attributes is a document object (#13).
	                if (config.attr && recurse && $target.nodeType === 1) {
	                    /**
	                     * clone live attribute list to an object structure {name: val}
	                     * @type {Object.<string, string>}
	                     */
	                    elestruct.attr = reduce($target.attributes, function(memo, attr) {
	                        if (!config.afilter || config.afilter[attr.name]) {
	                            memo[attr.name] = getAttributeValue($target, attr);
	                        }
	                        return memo;
	                    }, {});
	                }

	                // whether we should iterate the children of $target node
	                if (recurse && ((config.kids || config.charData) || (config.attr && config.descendents)) ) {
	                    /** @type {Array.<!Object>} : Array of custom clone */
	                    elestruct.kids = map($target.childNodes, copy);
	                }

	                recurse = config.descendents;
	            }
	            return elestruct;
	        })($target);
	    }

	    /**
	     * indexOf an element in a collection of custom nodes
	     *
	     * @param {NodeList} set
	     * @param {!Object} $node : A custom cloned node
	     * @param {number} idx : index to start the loop
	     * @return {number}
	     */
	    function indexOfCustomNode(set, $node, idx) {
	        return indexOf(set, $node, idx, JSCompiler_renameProperty("node"));
	    }

	    // using a non id (eg outerHTML or nodeValue) is extremely naive and will run into issues with nodes that may appear the same like <li></li>
	    var counter = 1; // don't use 0 as id (falsy)
	    /** @const */
	    var expando = "mo_id";

	    /**
	     * Attempt to uniquely id an element for hashing. We could optimize this for legacy browsers but it hopefully wont be called enough to be a concern
	     *
	     * @param {Node} $ele
	     * @return {(string|number)}
	     */
	    function getElementId($ele) {
	        try {
	            return $ele.id || ($ele[expando] = $ele[expando] || counter++);
	        } catch (o_O) { // ie <8 will throw if you set an unknown property on a text node
	            try {
	                return $ele.nodeValue; // naive
	            } catch (shitie) { // when text node is removed: https://gist.github.com/megawac/8355978 :(
	                return counter++;
	            }
	        }
	    }

	    /**
	     * **map** Apply a mapping function to each item of a set
	     * @param {Array|NodeList} set
	     * @param {Function} iterator
	     */
	    function map(set, iterator) {
	        var results = [];
	        for (var index = 0; index < set.length; index++) {
	            results[index] = iterator(set[index], index, set);
	        }
	        return results;
	    }

	    /**
	     * **Reduce** builds up a single result from a list of values
	     * @param {Array|NodeList|NamedNodeMap} set
	     * @param {Function} iterator
	     * @param {*} [memo] Initial value of the memo.
	     */
	    function reduce(set, iterator, memo) {
	        for (var index = 0; index < set.length; index++) {
	            memo = iterator(memo, set[index], index, set);
	        }
	        return memo;
	    }

	    /**
	     * **indexOf** find index of item in collection.
	     * @param {Array|NodeList} set
	     * @param {Object} item
	     * @param {number} idx
	     * @param {string} [prop] Property on set item to compare to item
	     */
	    function indexOf(set, item, idx, prop) {
	        for (/*idx = ~~idx*/; idx < set.length; idx++) {// start idx is always given as this is internal
	            if ((prop ? set[idx][prop] : set[idx]) === item) return idx;
	        }
	        return -1;
	    }

	    /**
	     * @param {Object} obj
	     * @param {(string|number)} prop
	     * @return {boolean}
	     */
	    function has(obj, prop) {
	        return obj[prop] !== undefined; // will be nicely inlined by gcc
	    }

	    // GCC hack see https://stackoverflow.com/a/23202438/1517919
	    function JSCompiler_renameProperty(a) {
	        return a;
	    }

	    return MutationObserver;
	}(void 0));

	var helpers = createCommonjsModule(function (module, exports) {



	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.getDocument = getDocument;
	exports.newMutationObserver = newMutationObserver;
	exports.getSetImmediate = getSetImmediate;

	var _mutationobserverShim = interopRequireDefault(MutationObserver);

	function newMutationObserver(onMutation) {
	  const MutationObserverConstructor = typeof window !== 'undefined' && typeof window.MutationObserver !== 'undefined' ? window.MutationObserver : _mutationobserverShim.default;
	  return new MutationObserverConstructor(onMutation);
	}

	function getDocument() {
	  /* istanbul ignore if */
	  if (typeof window === 'undefined') {
	    throw new Error('Could not find default container');
	  }

	  return window.document;
	}
	/*
	 * There are browsers for which `setImmediate` is not available. This
	 * serves as a polyfill of sorts, adopting `setTimeout` as the closest
	 * equivalent
	 */


	function getSetImmediate() {
	  /* istanbul ignore else */
	  if (typeof setImmediate === 'function') {
	    return setImmediate;
	  } else {
	    return function (fn) {
	      return setTimeout(fn, 0);
	    };
	  }
	}
	});

	unwrapExports(helpers);
	var helpers_1 = helpers.getDocument;
	var helpers_2 = helpers.newMutationObserver;
	var helpers_3 = helpers.getSetImmediate;

	var config_1 = createCommonjsModule(function (module, exports) {



	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.configure = configure;
	exports.getConfig = getConfig;

	var _extends2 = interopRequireDefault(_extends_1);

	// It would be cleaner for this to live inside './queries', but
	// other parts of the code assume that all exports from
	// './queries' are query functions.
	let config = {
	  testIdAttribute: 'data-testid',
	  // this is to support React's async `act` function.
	  // forcing react-testing-library to wrap all async functions would've been
	  // a total nightmare (consider wrapping every findBy* query and then also
	  // updating `within` so those would be wrapped too. Total nightmare).
	  // so we have this config option that's really only intended for
	  // react-testing-library to use. For that reason, this feature will remain
	  // undocumented.
	  asyncWrapper: cb => cb()
	};

	function configure(newConfig) {
	  if (typeof newConfig === 'function') {
	    // Pass the existing config out to the provided function
	    // and accept a delta in return
	    newConfig = newConfig(config);
	  } // Merge the incoming config delta


	  config = (0, _extends2.default)({}, config, newConfig);
	}

	function getConfig() {
	  return config;
	}
	});

	unwrapExports(config_1);
	var config_2 = config_1.configure;
	var config_3 = config_1.getConfig;

	var waitForElement_1 = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.waitForElement = waitForElementWrapper;





	function waitForElement(callback, {
	  container = (0, helpers.getDocument)(),
	  timeout = 4500,
	  mutationObserverOptions = {
	    subtree: true,
	    childList: true,
	    attributes: true,
	    characterData: true
	  }
	} = {}) {
	  return new Promise((resolve, reject) => {
	    if (typeof callback !== 'function') {
	      reject(new Error('waitForElement requires a callback as the first parameter'));
	      return;
	    }

	    let lastError;
	    const timer = setTimeout(onTimeout, timeout);
	    const observer = (0, helpers.newMutationObserver)(onMutation);
	    observer.observe(container, mutationObserverOptions);

	    function onDone(error, result) {
	      const setImmediate = (0, helpers.getSetImmediate)();
	      clearTimeout(timer);
	      setImmediate(() => observer.disconnect());

	      if (error) {
	        reject(error);
	      } else {
	        resolve(result);
	      }
	    }

	    function onMutation() {
	      try {
	        const result = callback();

	        if (result) {
	          onDone(null, result);
	        } // If `callback` returns falsy value, wait for the next mutation or timeout.

	      } catch (error) {
	        // Save the callback error to reject the promise with it.
	        lastError = error; // If `callback` throws an error, wait for the next mutation or timeout.
	      }
	    }

	    function onTimeout() {
	      onDone(lastError || new Error('Timed out in waitForElement.'), null);
	    }

	    onMutation();
	  });
	}

	function waitForElementWrapper(...args) {
	  return (0, config_1.getConfig)().asyncWrapper(() => waitForElement(...args));
	}
	});

	unwrapExports(waitForElement_1);
	var waitForElement_2 = waitForElement_1.waitForElement;

	var queryHelpers = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.debugDOM = debugDOM;
	exports.getElementError = getElementError;
	exports.getMultipleElementsFoundError = getMultipleElementsFoundError;
	exports.queryAllByAttribute = queryAllByAttribute;
	exports.queryByAttribute = queryByAttribute;
	exports.makeSingleQuery = makeSingleQuery;
	exports.makeGetAllQuery = makeGetAllQuery;
	exports.makeFindQuery = makeFindQuery;
	exports.buildQueries = buildQueries;







	/* eslint-disable complexity */
	function debugDOM(htmlElement) {
	  const limit = process.env.DEBUG_PRINT_LIMIT || 7000;
	  const inNode = typeof process !== 'undefined' && process.versions !== undefined && process.versions.node !== undefined;
	  /* istanbul ignore next */

	  const window = htmlElement.ownerDocument && htmlElement.ownerDocument.defaultView || undefined;
	  const inCypress = typeof commonjsGlobal !== 'undefined' && commonjsGlobal.Cypress || typeof window !== 'undefined' && window.Cypress;
	  /* istanbul ignore else */

	  if (inCypress) {
	    return '';
	  } else if (inNode) {
	    return (0, prettyDom.prettyDOM)(htmlElement, limit);
	  } else {
	    return (0, prettyDom.prettyDOM)(htmlElement, limit, {
	      highlight: false
	    });
	  }
	}
	/* eslint-enable complexity */


	function getElementError(message, container) {
	  return new Error([message, debugDOM(container)].filter(Boolean).join('\n\n'));
	}

	function getMultipleElementsFoundError(message, container) {
	  return getElementError(`${message}\n\n(If this is intentional, then use the \`*AllBy*\` variant of the query (like \`queryAllByText\`, \`getAllByText\`, or \`findAllByText\`)).`, container);
	}

	function queryAllByAttribute(attribute, container, text, {
	  exact = true,
	  collapseWhitespace,
	  trim,
	  normalizer
	} = {}) {
	  const matcher = exact ? matches_1.matches : matches_1.fuzzyMatches;
	  const matchNormalizer = (0, matches_1.makeNormalizer)({
	    collapseWhitespace,
	    trim,
	    normalizer
	  });
	  return Array.from(container.querySelectorAll(`[${attribute}]`)).filter(node => matcher(node.getAttribute(attribute), node, text, matchNormalizer));
	}

	function queryByAttribute(attribute, container, text, ...args) {
	  const els = queryAllByAttribute(attribute, container, text, ...args);

	  if (els.length > 1) {
	    throw getMultipleElementsFoundError(`Found multiple elements by [${attribute}=${text}]`, container);
	  }

	  return els[0] || null;
	} // this accepts a query function and returns a function which throws an error
	// if more than one elements is returned, otherwise it returns the first
	// element or null


	function makeSingleQuery(allQuery, getMultipleError) {
	  return (container, ...args) => {
	    const els = allQuery(container, ...args);

	    if (els.length > 1) {
	      throw getMultipleElementsFoundError(getMultipleError(container, ...args), container);
	    }

	    return els[0] || null;
	  };
	} // this accepts a query function and returns a function which throws an error
	// if an empty list of elements is returned


	function makeGetAllQuery(allQuery, getMissingError) {
	  return (container, ...args) => {
	    const els = allQuery(container, ...args);

	    if (!els.length) {
	      throw getElementError(getMissingError(container, ...args), container);
	    }

	    return els;
	  };
	} // this accepts a getter query function and returns a function which calls
	// waitForElement and passing a function which invokes the getter.


	function makeFindQuery(getter) {
	  return (container, text, options, waitForElementOptions) => (0, waitForElement_1.waitForElement)(() => getter(container, text, options), waitForElementOptions);
	}

	function buildQueries(queryAllBy, getMultipleError, getMissingError) {
	  const queryBy = makeSingleQuery(queryAllBy, getMultipleError);
	  const getAllBy = makeGetAllQuery(queryAllBy, getMissingError);
	  const getBy = makeSingleQuery(getAllBy, getMultipleError);
	  const findAllBy = makeFindQuery(getAllBy);
	  const findBy = makeFindQuery(getBy);
	  return [queryBy, getAllBy, getBy, findAllBy, findBy];
	}
	});

	unwrapExports(queryHelpers);
	var queryHelpers_1 = queryHelpers.debugDOM;
	var queryHelpers_2 = queryHelpers.getElementError;
	var queryHelpers_3 = queryHelpers.getMultipleElementsFoundError;
	var queryHelpers_4 = queryHelpers.queryAllByAttribute;
	var queryHelpers_5 = queryHelpers.queryByAttribute;
	var queryHelpers_6 = queryHelpers.makeSingleQuery;
	var queryHelpers_7 = queryHelpers.makeGetAllQuery;
	var queryHelpers_8 = queryHelpers.makeFindQuery;
	var queryHelpers_9 = queryHelpers.buildQueries;

	var allUtils = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});



	Object.keys(matches_1).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return matches_1[key];
	    }
	  });
	});



	Object.keys(getNodeText_1).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return getNodeText_1[key];
	    }
	  });
	});



	Object.keys(queryHelpers).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return queryHelpers[key];
	    }
	  });
	});



	Object.keys(config_1).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return config_1[key];
	    }
	  });
	});
	});

	unwrapExports(allUtils);

	var text = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.queryAllByText = queryAllByText;
	exports.findByText = exports.findAllByText = exports.getAllByText = exports.getByText = exports.queryByText = void 0;



	function queryAllByText(container, text, {
	  selector = '*',
	  exact = true,
	  collapseWhitespace,
	  trim,
	  ignore = 'script, style',
	  normalizer
	} = {}) {
	  const matcher = exact ? allUtils.matches : allUtils.fuzzyMatches;
	  const matchNormalizer = (0, allUtils.makeNormalizer)({
	    collapseWhitespace,
	    trim,
	    normalizer
	  });
	  let baseArray = [];

	  if (typeof container.matches === 'function' && container.matches(selector)) {
	    baseArray = [container];
	  }

	  return [...baseArray, ...Array.from(container.querySelectorAll(selector))].filter(node => !ignore || !node.matches(ignore)).filter(node => matcher((0, allUtils.getNodeText)(node), node, text, matchNormalizer));
	}

	const getMultipleError = (c, text) => `Found multiple elements with the text: ${text}`;

	const getMissingError = (c, text) => `Unable to find an element with the text: ${text}. This could be because the text is broken up by multiple elements. In this case, you can provide a function for your text matcher to make your matcher more flexible.`;

	const [queryByText, getAllByText, getByText, findAllByText, findByText] = (0, allUtils.buildQueries)(queryAllByText, getMultipleError, getMissingError);
	exports.findByText = findByText;
	exports.findAllByText = findAllByText;
	exports.getByText = getByText;
	exports.getAllByText = getAllByText;
	exports.queryByText = queryByText;
	});

	unwrapExports(text);
	var text_1 = text.queryAllByText;
	var text_2 = text.findByText;
	var text_3 = text.findAllByText;
	var text_4 = text.getAllByText;
	var text_5 = text.getByText;
	var text_6 = text.queryByText;

	var labelText = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.queryAllByLabelText = queryAllByLabelText;
	exports.getAllByLabelText = getAllByLabelText;
	exports.findByLabelText = exports.findAllByLabelText = exports.getByLabelText = exports.queryByLabelText = void 0;





	function queryAllLabelsByText(container, text$$1, {
	  exact = true,
	  trim,
	  collapseWhitespace,
	  normalizer
	} = {}) {
	  const matcher = exact ? allUtils.matches : allUtils.fuzzyMatches;
	  const matchNormalizer = (0, allUtils.makeNormalizer)({
	    collapseWhitespace,
	    trim,
	    normalizer
	  });
	  return Array.from(container.querySelectorAll('label')).filter(label => matcher(label.textContent, label, text$$1, matchNormalizer));
	}

	function queryAllByLabelText(container, text$$1, {
	  selector = '*',
	  exact = true,
	  collapseWhitespace,
	  trim,
	  normalizer
	} = {}) {
	  const matchNormalizer = (0, allUtils.makeNormalizer)({
	    collapseWhitespace,
	    trim,
	    normalizer
	  });
	  const labels = queryAllLabelsByText(container, text$$1, {
	    exact,
	    normalizer: matchNormalizer
	  });
	  const labelledElements = labels.map(label => {
	    if (label.control) {
	      return label.control;
	    }
	    /* istanbul ignore if */


	    if (label.getAttribute('for')) {
	      // we're using this notation because with the # selector we would have to escape special characters e.g. user.name
	      // see https://developer.mozilla.org/en-US/docs/Web/API/Document/querySelector#Escaping_special_characters
	      // <label for="someId">text</label><input id="someId" />
	      // .control support has landed in jsdom (https://github.com/jsdom/jsdom/issues/2175)
	      return container.querySelector(`[id="${label.getAttribute('for')}"]`);
	    }

	    if (label.getAttribute('id')) {
	      // <label id="someId">text</label><input aria-labelledby="someId" />
	      return container.querySelector(`[aria-labelledby~="${label.getAttribute('id')}"]`);
	    }

	    if (label.childNodes.length) {
	      // <label>text: <input /></label>
	      return label.querySelector(selector);
	    }

	    return null;
	  }).filter(label => label !== null).concat((0, allUtils.queryAllByAttribute)('aria-label', container, text$$1, {
	    exact
	  }));
	  const possibleAriaLabelElements = (0, text.queryAllByText)(container, text$$1, {
	    exact,
	    normalizer: matchNormalizer
	  }).filter(el => el.tagName !== 'LABEL'); // don't reprocess labels

	  const ariaLabelledElements = possibleAriaLabelElements.reduce((allLabelledElements, nextLabelElement) => {
	    const labelId = nextLabelElement.getAttribute('id');
	    if (!labelId) return allLabelledElements; // ARIA labels can label multiple elements

	    const labelledNodes = Array.from(container.querySelectorAll(`[aria-labelledby~="${labelId}"]`));
	    return allLabelledElements.concat(labelledNodes);
	  }, []);
	  return Array.from(new Set([...labelledElements, ...ariaLabelledElements]));
	} // the getAll* query would normally look like this:
	// const getAllByLabelText = makeGetAllQuery(
	//   queryAllByLabelText,
	//   (c, text) => `Unable to find a label with the text of: ${text}`,
	// )
	// however, we can give a more helpful error message than the generic one,
	// so we're writing this one out by hand.


	function getAllByLabelText(container, text$$1, ...rest) {
	  const els = queryAllByLabelText(container, text$$1, ...rest);

	  if (!els.length) {
	    const labels = queryAllLabelsByText(container, text$$1, ...rest);

	    if (labels.length) {
	      throw (0, allUtils.getElementError)(`Found a label with the text of: ${text$$1}, however no form control was found associated to that label. Make sure you're using the "for" attribute or "aria-labelledby" attribute correctly.`, container);
	    } else {
	      throw (0, allUtils.getElementError)(`Unable to find a label with the text of: ${text$$1}`, container);
	    }
	  }

	  return els;
	} // the reason mentioned above is the same reason we're not using buildQueries


	const getMultipleError = (c, text$$1) => `Found multiple elements with the text of: ${text$$1}`;

	const queryByLabelText = (0, allUtils.makeSingleQuery)(queryAllByLabelText, getMultipleError);
	exports.queryByLabelText = queryByLabelText;
	const getByLabelText = (0, allUtils.makeSingleQuery)(getAllByLabelText, getMultipleError);
	exports.getByLabelText = getByLabelText;
	const findAllByLabelText = (0, allUtils.makeFindQuery)(getAllByLabelText);
	exports.findAllByLabelText = findAllByLabelText;
	const findByLabelText = (0, allUtils.makeFindQuery)(getByLabelText);
	exports.findByLabelText = findByLabelText;
	});

	unwrapExports(labelText);
	var labelText_1 = labelText.queryAllByLabelText;
	var labelText_2 = labelText.getAllByLabelText;
	var labelText_3 = labelText.findByLabelText;
	var labelText_4 = labelText.findAllByLabelText;
	var labelText_5 = labelText.getByLabelText;
	var labelText_6 = labelText.queryByLabelText;

	var placeholderText = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.findByPlaceholderText = exports.findAllByPlaceholderText = exports.getAllByPlaceholderText = exports.getByPlaceholderText = exports.queryAllByPlaceholderText = exports.queryByPlaceholderText = void 0;



	const queryAllByPlaceholderText = allUtils.queryAllByAttribute.bind(null, 'placeholder');

	exports.queryAllByPlaceholderText = queryAllByPlaceholderText;

	const getMultipleError = (c, text) => `Found multiple elements with the placeholder text of: ${text}`;

	const getMissingError = (c, text) => `Unable to find an element with the placeholder text of: ${text}`;

	const [queryByPlaceholderText, getAllByPlaceholderText, getByPlaceholderText, findAllByPlaceholderText, findByPlaceholderText] = (0, allUtils.buildQueries)(queryAllByPlaceholderText, getMultipleError, getMissingError);
	exports.findByPlaceholderText = findByPlaceholderText;
	exports.findAllByPlaceholderText = findAllByPlaceholderText;
	exports.getByPlaceholderText = getByPlaceholderText;
	exports.getAllByPlaceholderText = getAllByPlaceholderText;
	exports.queryByPlaceholderText = queryByPlaceholderText;
	});

	unwrapExports(placeholderText);
	var placeholderText_1 = placeholderText.findByPlaceholderText;
	var placeholderText_2 = placeholderText.findAllByPlaceholderText;
	var placeholderText_3 = placeholderText.getAllByPlaceholderText;
	var placeholderText_4 = placeholderText.getByPlaceholderText;
	var placeholderText_5 = placeholderText.queryAllByPlaceholderText;
	var placeholderText_6 = placeholderText.queryByPlaceholderText;

	var displayValue = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.queryAllByDisplayValue = queryAllByDisplayValue;
	exports.findByDisplayValue = exports.findAllByDisplayValue = exports.getAllByDisplayValue = exports.getByDisplayValue = exports.queryByDisplayValue = void 0;



	function queryAllByDisplayValue(container, value, {
	  exact = true,
	  collapseWhitespace,
	  trim,
	  normalizer
	} = {}) {
	  const matcher = exact ? allUtils.matches : allUtils.fuzzyMatches;
	  const matchNormalizer = (0, allUtils.makeNormalizer)({
	    collapseWhitespace,
	    trim,
	    normalizer
	  });
	  return Array.from(container.querySelectorAll(`input,textarea,select`)).filter(node => {
	    if (node.tagName === 'SELECT') {
	      const selectedOptions = Array.from(node.options).filter(option => option.selected);
	      return selectedOptions.some(optionNode => matcher((0, allUtils.getNodeText)(optionNode), optionNode, value, matchNormalizer));
	    } else {
	      return matcher(node.value, node, value, matchNormalizer);
	    }
	  });
	}

	const getMultipleError = (c, value) => `Found multiple elements with the value: ${value}.`;

	const getMissingError = (c, value) => `Unable to find an element with the value: ${value}.`;

	const [queryByDisplayValue, getAllByDisplayValue, getByDisplayValue, findAllByDisplayValue, findByDisplayValue] = (0, allUtils.buildQueries)(queryAllByDisplayValue, getMultipleError, getMissingError);
	exports.findByDisplayValue = findByDisplayValue;
	exports.findAllByDisplayValue = findAllByDisplayValue;
	exports.getByDisplayValue = getByDisplayValue;
	exports.getAllByDisplayValue = getAllByDisplayValue;
	exports.queryByDisplayValue = queryByDisplayValue;
	});

	unwrapExports(displayValue);
	var displayValue_1 = displayValue.queryAllByDisplayValue;
	var displayValue_2 = displayValue.findByDisplayValue;
	var displayValue_3 = displayValue.findAllByDisplayValue;
	var displayValue_4 = displayValue.getAllByDisplayValue;
	var displayValue_5 = displayValue.getByDisplayValue;
	var displayValue_6 = displayValue.queryByDisplayValue;

	var altText = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.queryAllByAltText = queryAllByAltText;
	exports.findByAltText = exports.findAllByAltText = exports.getAllByAltText = exports.getByAltText = exports.queryByAltText = void 0;



	function queryAllByAltText(container, alt, {
	  exact = true,
	  collapseWhitespace,
	  trim,
	  normalizer
	} = {}) {
	  const matcher = exact ? allUtils.matches : allUtils.fuzzyMatches;
	  const matchNormalizer = (0, allUtils.makeNormalizer)({
	    collapseWhitespace,
	    trim,
	    normalizer
	  });
	  return Array.from(container.querySelectorAll('img,input,area')).filter(node => matcher(node.getAttribute('alt'), node, alt, matchNormalizer));
	}

	const getMultipleError = (c, alt) => `Found multiple elements with the alt text: ${alt}`;

	const getMissingError = (c, alt) => `Unable to find an element with the alt text: ${alt}`;

	const [queryByAltText, getAllByAltText, getByAltText, findAllByAltText, findByAltText] = (0, allUtils.buildQueries)(queryAllByAltText, getMultipleError, getMissingError);
	exports.findByAltText = findByAltText;
	exports.findAllByAltText = findAllByAltText;
	exports.getByAltText = getByAltText;
	exports.getAllByAltText = getAllByAltText;
	exports.queryByAltText = queryByAltText;
	});

	unwrapExports(altText);
	var altText_1 = altText.queryAllByAltText;
	var altText_2 = altText.findByAltText;
	var altText_3 = altText.findAllByAltText;
	var altText_4 = altText.getAllByAltText;
	var altText_5 = altText.getByAltText;
	var altText_6 = altText.queryByAltText;

	var title = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.queryAllByTitle = queryAllByTitle;
	exports.findByTitle = exports.findAllByTitle = exports.getAllByTitle = exports.getByTitle = exports.queryByTitle = void 0;



	function queryAllByTitle(container, text, {
	  exact = true,
	  collapseWhitespace,
	  trim,
	  normalizer
	} = {}) {
	  const matcher = exact ? allUtils.matches : allUtils.fuzzyMatches;
	  const matchNormalizer = (0, allUtils.makeNormalizer)({
	    collapseWhitespace,
	    trim,
	    normalizer
	  });
	  return Array.from(container.querySelectorAll('[title], svg > title')).filter(node => matcher(node.getAttribute('title'), node, text, matchNormalizer) || matcher((0, allUtils.getNodeText)(node), node, text, matchNormalizer));
	}

	const getMultipleError = (c, title) => `Found multiple elements with the title: ${title}.`;

	const getMissingError = (c, title) => `Unable to find an element with the title: ${title}.`;

	const [queryByTitle, getAllByTitle, getByTitle, findAllByTitle, findByTitle] = (0, allUtils.buildQueries)(queryAllByTitle, getMultipleError, getMissingError);
	exports.findByTitle = findByTitle;
	exports.findAllByTitle = findAllByTitle;
	exports.getByTitle = getByTitle;
	exports.getAllByTitle = getAllByTitle;
	exports.queryByTitle = queryByTitle;
	});

	unwrapExports(title);
	var title_1 = title.queryAllByTitle;
	var title_2 = title.findByTitle;
	var title_3 = title.findAllByTitle;
	var title_4 = title.getAllByTitle;
	var title_5 = title.getByTitle;
	var title_6 = title.queryByTitle;

	var role = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.findByRole = exports.findAllByRole = exports.getByRole = exports.getAllByRole = exports.queryAllByRole = exports.queryByRole = void 0;



	const queryAllByRole = allUtils.queryAllByAttribute.bind(null, 'role');

	exports.queryAllByRole = queryAllByRole;

	const getMultipleError = (c, id) => `Found multiple elements by [role=${id}]`;

	const getMissingError = (c, id) => `Unable to find an element by [role=${id}]`;

	const [queryByRole, getAllByRole, getByRole, findAllByRole, findByRole] = (0, allUtils.buildQueries)(queryAllByRole, getMultipleError, getMissingError);
	exports.findByRole = findByRole;
	exports.findAllByRole = findAllByRole;
	exports.getByRole = getByRole;
	exports.getAllByRole = getAllByRole;
	exports.queryByRole = queryByRole;
	});

	unwrapExports(role);
	var role_1 = role.findByRole;
	var role_2 = role.findAllByRole;
	var role_3 = role.getByRole;
	var role_4 = role.getAllByRole;
	var role_5 = role.queryAllByRole;
	var role_6 = role.queryByRole;

	var testId = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.findByTestId = exports.findAllByTestId = exports.getAllByTestId = exports.getByTestId = exports.queryAllByTestId = exports.queryByTestId = void 0;



	const getTestIdAttribute = () => (0, allUtils.getConfig)().testIdAttribute;

	const queryAllByTestId = (...args) => (0, allUtils.queryAllByAttribute)(getTestIdAttribute(), ...args);

	exports.queryAllByTestId = queryAllByTestId;

	const getMultipleError = (c, id) => `Found multiple elements by: [${getTestIdAttribute()}="${id}"]`;

	const getMissingError = (c, id) => `Unable to find an element by: [${getTestIdAttribute()}="${id}"]`;

	const [queryByTestId, getAllByTestId, getByTestId, findAllByTestId, findByTestId] = (0, allUtils.buildQueries)(queryAllByTestId, getMultipleError, getMissingError);
	exports.findByTestId = findByTestId;
	exports.findAllByTestId = findAllByTestId;
	exports.getByTestId = getByTestId;
	exports.getAllByTestId = getAllByTestId;
	exports.queryByTestId = queryByTestId;
	});

	unwrapExports(testId);
	var testId_1 = testId.findByTestId;
	var testId_2 = testId.findAllByTestId;
	var testId_3 = testId.getAllByTestId;
	var testId_4 = testId.getByTestId;
	var testId_5 = testId.queryAllByTestId;
	var testId_6 = testId.queryByTestId;

	var queries = createCommonjsModule(function (module, exports) {

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});



	Object.keys(labelText).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return labelText[key];
	    }
	  });
	});



	Object.keys(placeholderText).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return placeholderText[key];
	    }
	  });
	});



	Object.keys(text).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return text[key];
	    }
	  });
	});



	Object.keys(displayValue).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return displayValue[key];
	    }
	  });
	});



	Object.keys(altText).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return altText[key];
	    }
	  });
	});



	Object.keys(title).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return title[key];
	    }
	  });
	});



	Object.keys(role).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return role[key];
	    }
	  });
	});



	Object.keys(testId).forEach(function (key) {
	  if (key === "default" || key === "__esModule") return;
	  Object.defineProperty(exports, key, {
	    enumerable: true,
	    get: function () {
	      return testId[key];
	    }
	  });
	});
	});

	unwrapExports(queries);

	exports.getNodeText = getNodeText_2;
	exports.__moduleExports = queries;

	return exports;

}({}));
